Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::AddNoteRequest
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::AddNoteRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Request to add a note.
Instance Attribute Summary collapse
-
#note ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Note
A text note attached to the proposal to facilitate the communication between buyers and sellers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AddNoteRequest
constructor
A new instance of AddNoteRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AddNoteRequest
Returns a new instance of AddNoteRequest.
183 184 185 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#note ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Note
A text note attached to the proposal to facilitate the communication between
buyers and sellers.
Corresponds to the JSON property note
181 182 183 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 181 def note @note end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
188 189 190 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 188 def update!(**args) @note = args[:note] if args.key?(:note) end |