Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Client
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Client
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
A client represents an agency, a brand, or an advertiser customer of the buyer. Based on the client's role, its client users will have varying levels of restricted access to the Marketplace and certain other sections of the Authorized Buyers UI.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Required.
-
#name ⇒ String
Output only.
-
#partner_client_id ⇒ String
Arbitrary unique identifier provided by the buyer.
-
#role ⇒ String
Required.
-
#seller_visible ⇒ Boolean
(also: #seller_visible?)
Whether the client will be visible to sellers.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Client
constructor
A new instance of Client.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Client
Returns a new instance of Client.
390 391 392 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 390 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Required. Display name shown to publishers. Must be unique for clients without
partnerClientId specified. Maximum length of 255 characters is allowed.
Corresponds to the JSON property displayName
357 358 359 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 357 def display_name @display_name end |
#name ⇒ String
Output only. The resource name of the client. Format: buyers/accountId/
clients/clientAccountId`
Corresponds to the JSON propertyname`
363 364 365 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 363 def name @name end |
#partner_client_id ⇒ String
Arbitrary unique identifier provided by the buyer. This field can be used to
associate a client with an identifier in the namespace of the buyer, lookup
clients by that identifier and verify whether an Authorized Buyers account of
the client already exists. If present, must be unique across all the clients.
Corresponds to the JSON property partnerClientId
371 372 373 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 371 def partner_client_id @partner_client_id end |
#role ⇒ String
Required. The role assigned to the client. Each role implies a set of
permissions granted to the client.
Corresponds to the JSON property role
377 378 379 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 377 def role @role end |
#seller_visible ⇒ Boolean Also known as: seller_visible?
Whether the client will be visible to sellers.
Corresponds to the JSON property sellerVisible
382 383 384 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 382 def seller_visible @seller_visible end |
#state ⇒ String
Output only. The state of the client.
Corresponds to the JSON property state
388 389 390 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 388 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
395 396 397 398 399 400 401 402 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 395 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @partner_client_id = args[:partner_client_id] if args.key?(:partner_client_id) @role = args[:role] if args.key?(:role) @seller_visible = args[:seller_visible] if args.key?(:seller_visible) @state = args[:state] if args.key?(:state) end |