Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CreativeRequirements
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CreativeRequirements
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Message captures data about the creatives in the deal.
Instance Attribute Summary collapse
-
#creative_format ⇒ String
Output only.
-
#creative_pre_approval_policy ⇒ String
Output only.
-
#creative_safe_frame_compatibility ⇒ String
Output only.
-
#max_ad_duration_ms ⇒ Fixnum
Output only.
-
#programmatic_creative_source ⇒ String
Output only.
-
#skippable_ad_type ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CreativeRequirements
constructor
A new instance of CreativeRequirements.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CreativeRequirements
Returns a new instance of CreativeRequirements.
504 505 506 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 504 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creative_format ⇒ String
Output only. The format of the creative, only applicable for programmatic
guaranteed and preferred deals.
Corresponds to the JSON property creativeFormat
473 474 475 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 473 def creative_format @creative_format end |
#creative_pre_approval_policy ⇒ String
Output only. Specifies the creative pre-approval policy.
Corresponds to the JSON property creativePreApprovalPolicy
478 479 480 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 478 def creative_pre_approval_policy @creative_pre_approval_policy end |
#creative_safe_frame_compatibility ⇒ String
Output only. Specifies whether the creative is safeFrame compatible.
Corresponds to the JSON property creativeSafeFrameCompatibility
483 484 485 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 483 def creative_safe_frame_compatibility @creative_safe_frame_compatibility end |
#max_ad_duration_ms ⇒ Fixnum
Output only. The max duration of the video creative in milliseconds. only
applicable for deals with video creatives.
Corresponds to the JSON property maxAdDurationMs
489 490 491 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 489 def max_ad_duration_ms @max_ad_duration_ms end |
#programmatic_creative_source ⇒ String
Output only. Specifies the creative source for programmatic deals. PUBLISHER
means creative is provided by seller and ADVERTISER means creative is provided
by the buyer.
Corresponds to the JSON property programmaticCreativeSource
496 497 498 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 496 def programmatic_creative_source @programmatic_creative_source end |
#skippable_ad_type ⇒ String
Output only. Skippable video ads allow viewers to skip ads after 5 seconds.
Only applicable for deals with video creatives.
Corresponds to the JSON property skippableAdType
502 503 504 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 502 def skippable_ad_type @skippable_ad_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
509 510 511 512 513 514 515 516 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 509 def update!(**args) @creative_format = args[:creative_format] if args.key?(:creative_format) @creative_pre_approval_policy = args[:creative_pre_approval_policy] if args.key?(:creative_pre_approval_policy) @creative_safe_frame_compatibility = args[:creative_safe_frame_compatibility] if args.key?(:creative_safe_frame_compatibility) @max_ad_duration_ms = args[:max_ad_duration_ms] if args.key?(:max_ad_duration_ms) @programmatic_creative_source = args[:programmatic_creative_source] if args.key?(:programmatic_creative_source) @skippable_ad_type = args[:skippable_ad_type] if args.key?(:skippable_ad_type) end |