Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CuratedPackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Represents a curated package of inventory created and managed by a Curator.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CuratedPackage

Returns a new instance of CuratedPackage.



617
618
619
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 617

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_settingsGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::AccessControlSettings

Settings for controlling access to a curated package. Corresponds to the JSON property accessSettings



553
554
555
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 553

def access_settings
  @access_settings
end

#create_timeString

Output only. The timestamp when the curated package was created. Can be used to filter the response of the curatedPackages.list method. Corresponds to the JSON property createTime

Returns:

  • (String)


559
560
561
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 559

def create_time
  @create_time
end

#curation_fee_visibilityString

Optional. Immutable. The visibility of the combined curation package fee and data segment fees (the total curation fee). Corresponds to the JSON property curationFeeVisibility

Returns:

  • (String)


565
566
567
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 565

def curation_fee_visibility
  @curation_fee_visibility
end

#descriptionString

Optional. A description of the curated package, provided by the curator. Corresponds to the JSON property description

Returns:

  • (String)


570
571
572
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 570

def description
  @description
end

#display_nameString

Required. The display name assigned to the curated package by the curator. Can be used to filter the response of the curatedPackages.list method. Corresponds to the JSON property displayName

Returns:

  • (String)


576
577
578
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 576

def display_name
  @display_name
end

#fee_cpmGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::Money

Represents an amount of money with its currency type. Corresponds to the JSON property feeCpm



581
582
583
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 581

def fee_cpm
  @fee_cpm
end

#floor_price_cpmGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::Money

Represents an amount of money with its currency type. Corresponds to the JSON property floorPriceCpm



586
587
588
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 586

def floor_price_cpm
  @floor_price_cpm
end

#millipercent_of_media_feeFixnum

Optional. The fee will be charged as a percentage of the impression cost, represented in millipercent. For example, 1% is represented as 1000. Corresponds to the JSON property millipercentOfMediaFee

Returns:

  • (Fixnum)


592
593
594
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 592

def millipercent_of_media_fee
  @millipercent_of_media_fee
end

#nameString

Identifier. The unique resource name for the curated package. Format: curators/accountId/curatedPackages/curatedPackageId` Corresponds to the JSON propertyname`

Returns:

  • (String)


598
599
600
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 598

def name
  @name
end

#stateString

Output only. The state of the curated package. Can be used to filter the response of the curatedPackages.list method. Corresponds to the JSON property state

Returns:

  • (String)


604
605
606
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 604

def state
  @state
end

#targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::PackageTargeting

Targeting criteria for curated and auction packages. Corresponds to the JSON property targeting



609
610
611
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 609

def targeting
  @targeting
end

#update_timeString

Output only. The timestamp when the curated package was last updated. Can be used to filter the response of the curatedPackages.list method. Corresponds to the JSON property updateTime

Returns:

  • (String)


615
616
617
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 615

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



622
623
624
625
626
627
628
629
630
631
632
633
634
635
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 622

def update!(**args)
  @access_settings = args[:access_settings] if args.key?(:access_settings)
  @create_time = args[:create_time] if args.key?(:create_time)
  @curation_fee_visibility = args[:curation_fee_visibility] if args.key?(:curation_fee_visibility)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @fee_cpm = args[:fee_cpm] if args.key?(:fee_cpm)
  @floor_price_cpm = args[:floor_price_cpm] if args.key?(:floor_price_cpm)
  @millipercent_of_media_fee = args[:millipercent_of_media_fee] if args.key?(:millipercent_of_media_fee)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @targeting = args[:targeting] if args.key?(:targeting)
  @update_time = args[:update_time] if args.key?(:update_time)
end