Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DayPartTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Represents Daypart targeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DayPartTargeting

Returns a new instance of DayPartTargeting.



735
736
737
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 735

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#day_partsArray<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DayPart>

The targeted weekdays and times Corresponds to the JSON property dayParts



728
729
730
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 728

def day_parts
  @day_parts
end

#time_zone_typeString

The time zone type of the day parts Corresponds to the JSON property timeZoneType

Returns:

  • (String)


733
734
735
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 733

def time_zone_type
  @time_zone_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



740
741
742
743
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 740

def update!(**args)
  @day_parts = args[:day_parts] if args.key?(:day_parts)
  @time_zone_type = args[:time_zone_type] if args.key?(:time_zone_type)
end