Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DealPausingInfo
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DealPausingInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Information related to deal pausing.
Instance Attribute Summary collapse
-
#pause_reason ⇒ String
The reason for the pausing of the deal; empty for active deals.
-
#pause_role ⇒ String
The party that first paused the deal; unspecified for active deals.
-
#pausing_consented ⇒ Boolean
(also: #pausing_consented?)
Whether pausing is consented between buyer and seller for the deal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DealPausingInfo
constructor
A new instance of DealPausingInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DealPausingInfo
Returns a new instance of DealPausingInfo.
989 990 991 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 989 def initialize(**args) update!(**args) end |
Instance Attribute Details
#pause_reason ⇒ String
The reason for the pausing of the deal; empty for active deals.
Corresponds to the JSON property pauseReason
976 977 978 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 976 def pause_reason @pause_reason end |
#pause_role ⇒ String
The party that first paused the deal; unspecified for active deals.
Corresponds to the JSON property pauseRole
981 982 983 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 981 def pause_role @pause_role end |
#pausing_consented ⇒ Boolean Also known as: pausing_consented?
Whether pausing is consented between buyer and seller for the deal.
Corresponds to the JSON property pausingConsented
986 987 988 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 986 def @pausing_consented end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
994 995 996 997 998 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 994 def update!(**args) @pause_reason = args[:pause_reason] if args.key?(:pause_reason) @pause_role = args[:pause_role] if args.key?(:pause_role) @pausing_consented = args[:pausing_consented] if args.key?(:pausing_consented) end |