Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::FirstPartyMobileApplicationTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Represents a list of targeted and excluded mobile application IDs that publishers own. Android App ID, for example, com.google.android.apps.maps, can be found in Google Play Store URL. iOS App ID (which is a number) can be found at the end of iTunes store URL. First party mobile applications is either included or excluded.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirstPartyMobileApplicationTargeting

Returns a new instance of FirstPartyMobileApplicationTargeting.



1161
1162
1163
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1161

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#excluded_app_idsArray<String>

A list of application IDs to be excluded. Corresponds to the JSON property excludedAppIds

Returns:

  • (Array<String>)


1154
1155
1156
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1154

def excluded_app_ids
  @excluded_app_ids
end

#targeted_app_idsArray<String>

A list of application IDs to be included. Corresponds to the JSON property targetedAppIds

Returns:

  • (Array<String>)


1159
1160
1161
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1159

def targeted_app_ids
  @targeted_app_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1166
1167
1168
1169
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1166

def update!(**args)
  @excluded_app_ids = args[:excluded_app_ids] if args.key?(:excluded_app_ids)
  @targeted_app_ids = args[:targeted_app_ids] if args.key?(:targeted_app_ids)
end