Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ListClientUsersResponse
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ListClientUsersResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Response message for the list method.
Instance Attribute Summary collapse
-
#client_users ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ClientUser>
The returned list of client users.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListClientUsersResponse
constructor
A new instance of ListClientUsersResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListClientUsersResponse
Returns a new instance of ListClientUsersResponse.
1286 1287 1288 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1286 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_users ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ClientUser>
The returned list of client users.
Corresponds to the JSON property clientUsers
1277 1278 1279 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1277 def client_users @client_users end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
ListClientUsersRequest.pageToken field in the subsequent call to the list
method to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
1284 1285 1286 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1284 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1291 1292 1293 1294 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1291 def update!(**args) @client_users = args[:client_users] if args.key?(:client_users) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |