Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ListClientsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Response message for the list method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListClientsResponse

Returns a new instance of ListClientsResponse.



1320
1321
1322
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1320

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clientsArray<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Client>

The returned list of clients. Corresponds to the JSON property clients



1311
1312
1313
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1311

def clients
  @clients
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the ListClientsRequest.pageToken field in the subsequent call to the list method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1318
1319
1320
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1318

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1325
1326
1327
1328
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1325

def update!(**args)
  @clients = args[:clients] if args.key?(:clients)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end