Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ListCuratedPackagesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Response message for ListCuratedPackages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListCuratedPackagesResponse

Returns a new instance of ListCuratedPackagesResponse.



1348
1349
1350
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#curated_packagesArray<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CuratedPackage>

The list of curated packages. Corresponds to the JSON property curatedPackages



1338
1339
1340
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1338

def curated_packages
  @curated_packages
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the ListCuratedPackagesRequest.pageToken field in the subsequent call to ListCuratedPackages method to retrieve the next page of results. If empty, then there are no more results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1346
1347
1348
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1346

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1353
1354
1355
1356
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1353

def update!(**args)
  @curated_packages = args[:curated_packages] if args.key?(:curated_packages)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end