Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ListDataSegmentsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Response message for listing data segments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListDataSegmentsResponse

Returns a new instance of ListDataSegmentsResponse.



1375
1376
1377
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_segmentsArray<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DataSegment>

The list of data segments. Corresponds to the JSON property dataSegments



1366
1367
1368
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1366

def data_segments
  @data_segments
end

#next_page_tokenString

Continuation token for fetching the next page of results. Pass this value in the ListDataSegmentsRequest.pageToken field in the subsequent call to the ListDataSegments method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1373
1374
1375
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1373

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1380
1381
1382
1383
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1380

def update!(**args)
  @data_segments = args[:data_segments] if args.key?(:data_segments)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end