Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::MediaPlanner

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Represents a media planner account.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MediaPlanner

Returns a new instance of MediaPlanner.



1628
1629
1630
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

Output only. Account ID of the media planner. Corresponds to the JSON property accountId

Returns:

  • (String)


1606
1607
1608
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1606

def 
  @account_id
end

#ancestor_namesArray<String>

Output only. The ancestor names of the media planner. Format: mediaPlanners/ mediaPlannerAccountId`Can be used to filter the response of the mediaPlanners.list method. Corresponds to the JSON propertyancestorNames`

Returns:

  • (Array<String>)


1613
1614
1615
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1613

def ancestor_names
  @ancestor_names
end

#display_nameString

Output only. The display name of the media planner. Can be used to filter the response of the mediaPlanners.list method. Corresponds to the JSON property displayName

Returns:

  • (String)


1619
1620
1621
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1619

def display_name
  @display_name
end

#nameString

Identifier. The unique resource name of the media planner. Format: mediaPlanners/mediaPlannerAccountId`Can be used to filter the response of the mediaPlanners.list method. Corresponds to the JSON propertyname`

Returns:

  • (String)


1626
1627
1628
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1626

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1633
1634
1635
1636
1637
1638
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1633

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @ancestor_names = args[:ancestor_names] if args.key?(:ancestor_names)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
end