Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::MobileApplicationTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Mobile application targeting settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MobileApplicationTargeting

Returns a new instance of MobileApplicationTargeting.



1633
1634
1635
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#first_party_targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::FirstPartyMobileApplicationTargeting

Represents a list of targeted and excluded mobile application IDs that publishers own. Android App ID, for example, com.google.android.apps.maps, can be found in Google Play Store URL. iOS App ID (which is a number) can be found at the end of iTunes store URL. First party mobile applications is either included or excluded. Corresponds to the JSON property firstPartyTargeting



1631
1632
1633
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1631

def first_party_targeting
  @first_party_targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1638
1639
1640
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1638

def update!(**args)
  @first_party_targeting = args[:first_party_targeting] if args.key?(:first_party_targeting)
end