Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::OperatingSystemTargeting
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::OperatingSystemTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Represents targeting information for operating systems.
Instance Attribute Summary collapse
-
#operating_system_criteria ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
-
#operating_system_version_criteria ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperatingSystemTargeting
constructor
A new instance of OperatingSystemTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperatingSystemTargeting
Returns a new instance of OperatingSystemTargeting.
1743 1744 1745 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1743 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operating_system_criteria ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property operatingSystemCriteria
1734 1735 1736 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1734 def @operating_system_criteria end |
#operating_system_version_criteria ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property operatingSystemVersionCriteria
1741 1742 1743 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1741 def @operating_system_version_criteria end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1748 1749 1750 1751 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1748 def update!(**args) @operating_system_criteria = args[:operating_system_criteria] if args.key?(:operating_system_criteria) @operating_system_version_criteria = args[:operating_system_version_criteria] if args.key?(:operating_system_version_criteria) end |