Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PreferredDealTerms
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PreferredDealTerms
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Pricing terms for Preferred Deals.
Instance Attribute Summary collapse
-
#fixed_price ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Price
Represents a price and a pricing type for a deal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreferredDealTerms
constructor
A new instance of PreferredDealTerms.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreferredDealTerms
Returns a new instance of PreferredDealTerms.
2101 2102 2103 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2101 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fixed_price ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Price
Represents a price and a pricing type for a deal.
Corresponds to the JSON property fixedPrice
2099 2100 2101 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2099 def fixed_price @fixed_price end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2106 2107 2108 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2106 def update!(**args) @fixed_price = args[:fixed_price] if args.key?(:fixed_price) end |