Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Price

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Represents a price and a pricing type for a deal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Price

Returns a new instance of Price.



2139
2140
2141
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2139

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amountGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::Money

Represents an amount of money with its currency type. Corresponds to the JSON property amount



2132
2133
2134
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2132

def amount
  @amount
end

#typeString

The pricing type for the deal. Corresponds to the JSON property type

Returns:

  • (String)


2137
2138
2139
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2137

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2144
2145
2146
2147
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2144

def update!(**args)
  @amount = args[:amount] if args.key?(:amount)
  @type = args[:type] if args.key?(:type)
end