Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PrivateAuctionTerms

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Pricing terms for Private Auctions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivateAuctionTerms

Returns a new instance of PrivateAuctionTerms.



2152
2153
2154
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2152

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#floor_priceGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::Price

Represents a price and a pricing type for a deal. Corresponds to the JSON property floorPrice



2143
2144
2145
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2143

def floor_price
  @floor_price
end

#open_auction_allowedBoolean Also known as: open_auction_allowed?

Output only. True if open auction buyers are allowed to compete with invited buyers in this private auction. Corresponds to the JSON property openAuctionAllowed

Returns:

  • (Boolean)


2149
2150
2151
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2149

def open_auction_allowed
  @open_auction_allowed
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2157
2158
2159
2160
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2157

def update!(**args)
  @floor_price = args[:floor_price] if args.key?(:floor_price)
  @open_auction_allowed = args[:open_auction_allowed] if args.key?(:open_auction_allowed)
end