Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PrivateData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Buyers are allowed to store certain types of private data in a proposal.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PrivateData

Returns a new instance of PrivateData.



2173
2174
2175
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#reference_idString

A buyer specified reference ID. This can be queried in the list operations ( max-length: 1024 unicode code units). Corresponds to the JSON property referenceId

Returns:

  • (String)


2171
2172
2173
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2171

def reference_id
  @reference_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2178
2179
2180
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2178

def update!(**args)
  @reference_id = args[:reference_id] if args.key?(:reference_id)
end