Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::SubscribeClientsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Request message for SubscribeAuctionPackageClients.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubscribeClientsRequest

Returns a new instance of SubscribeClientsRequest.



2786
2787
2788
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2786

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clientsArray<String>

Optional. A list of client buyers to subscribe to the auction package, with client buyer in the format buyers/accountId/clients/clientAccountId`. The current buyer will be subscribed to the auction package regardless of the list contents if not already. Corresponds to the JSON propertyclients`

Returns:

  • (Array<String>)


2784
2785
2786
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2784

def clients
  @clients
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2791
2792
2793
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2791

def update!(**args)
  @clients = args[:clients] if args.key?(:clients)
end