Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::UpdateDealRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Request message for updating the deal at the given revision number.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpdateDealRequest

Returns a new instance of UpdateDealRequest.



2992
2993
2994
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dealGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::Deal

A deal represents a segment of inventory for displaying ads that contains the terms and targeting information that is used for serving as well as the deal stats and status. Note: A proposal may contain multiple deals. Corresponds to the JSON property deal



2977
2978
2979
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2977

def deal
  @deal
end

#update_maskString

List of fields to be updated. If empty or unspecified, the service will update all fields populated in the update request excluding the output only fields and primitive fields with default value. Note that explicit field mask is required in order to reset a primitive field back to its default value, for example, false for boolean fields, 0 for integer fields. A special field mask consisting of a single path "*" can be used to indicate full replacement(the equivalent of PUT method), updatable fields unset or unspecified in the input will be cleared or set to default value. Output only fields will be ignored regardless of the value of updateMask. Corresponds to the JSON property updateMask

Returns:

  • (String)


2990
2991
2992
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2990

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2997
2998
2999
3000
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2997

def update!(**args)
  @deal = args[:deal] if args.key?(:deal)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end