Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::VideoPlayerSizeTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Represents the size of the video player that can be targeted. Both width and height are required to be set to non-zero values.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoPlayerSizeTargeting

Returns a new instance of VideoPlayerSizeTargeting.



3038
3039
3040
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 3038

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#minimum_heightFixnum

Required. The minimum height of the video player in pixels. Corresponds to the JSON property minimumHeight

Returns:

  • (Fixnum)


3031
3032
3033
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 3031

def minimum_height
  @minimum_height
end

#minimum_widthFixnum

Required. The minimum width of the video player in pixels. Corresponds to the JSON property minimumWidth

Returns:

  • (Fixnum)


3036
3037
3038
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 3036

def minimum_width
  @minimum_width
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3043
3044
3045
3046
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 3043

def update!(**args)
  @minimum_height = args[:minimum_height] if args.key?(:minimum_height)
  @minimum_width = args[:minimum_width] if args.key?(:minimum_width)
end