Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::AccessControlSettings
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::AccessControlSettings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Settings for controlling access to a curated package.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ AccessControlSettings
constructor
A new instance of AccessControlSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AccessControlSettings
Returns a new instance of AccessControlSettings.
57 58 59 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 57 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowlisted_media_planners ⇒ Array<String>
Required. Immutable. The list of media planners that are explicitly granted
access to the curated package. Eligible media planners can be found in the
mediaPlanners.list method. Only a single media planner may be allowlisted at
this time. Format: mediaPlanners/mediaPlannerAccountId`
Corresponds to the JSON propertyallowlistedMediaPlanners`
55 56 57 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 55 def allowlisted_media_planners @allowlisted_media_planners end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62 63 64 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 62 def update!(**args) @allowlisted_media_planners = args[:allowlisted_media_planners] if args.key?(:allowlisted_media_planners) end |