Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::AddCreativeRequest
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::AddCreativeRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Request message for adding creative to be used in the bidding process for the finalized deal.
Instance Attribute Summary collapse
-
#creative ⇒ String
Name of the creative to add to the finalized deal, in the format
buyers/buyerAccountId/creatives/creativeId``.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AddCreativeRequest
constructor
A new instance of AddCreativeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AddCreativeRequest
Returns a new instance of AddCreativeRequest.
163 164 165 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 163 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creative ⇒ String
Name of the creative to add to the finalized deal, in the format buyers/
buyerAccountId/creatives/creativeId`. See creative.name.
Corresponds to the JSON propertycreative`
161 162 163 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 161 def creative @creative end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
168 169 170 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 168 def update!(**args) @creative = args[:creative] if args.key?(:creative) end |