Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ClientUser
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ClientUser
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
A user of a client who has restricted access to the Marketplace and certain other sections of the Authorized Buyers UI based on the role granted to the associated client.
Instance Attribute Summary collapse
-
#email ⇒ String
Required.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ClientUser
constructor
A new instance of ClientUser.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ClientUser
Returns a new instance of ClientUser.
428 429 430 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 428 def initialize(**args) update!(**args) end |
Instance Attribute Details
#email ⇒ String
Required. The client user's email address that has to be unique across all
users for the same client.
Corresponds to the JSON property email
415 416 417 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 415 def email @email end |
#name ⇒ String
Output only. The resource name of the client user. Format: buyers/accountId/
clients/clientAccountId/users/userId`
Corresponds to the JSON propertyname`
421 422 423 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 421 def name @name end |
#state ⇒ String
Output only. The state of the client user.
Corresponds to the JSON property state
426 427 428 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 426 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
433 434 435 436 437 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 433 def update!(**args) @email = args[:email] if args.key?(:email) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) end |