Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CuratedPackage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Represents a curated package of inventory created and managed by a Curator.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CuratedPackage

Returns a new instance of CuratedPackage.



605
606
607
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 605

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_settingsGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::AccessControlSettings

Settings for controlling access to a curated package. Corresponds to the JSON property accessSettings



553
554
555
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 553

def access_settings
  @access_settings
end

#create_timeString

Output only. The timestamp when the curated package was created. Can be used to filter the response of the curatedPackages.list method. Corresponds to the JSON property createTime

Returns:

  • (String)


559
560
561
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 559

def create_time
  @create_time
end

#descriptionString

Optional. A description of the curated package, provided by the curator. Corresponds to the JSON property description

Returns:

  • (String)


564
565
566
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 564

def description
  @description
end

#display_nameString

Required. The display name assigned to the curated package by the curator. Can be used to filter the response of the curatedPackages.list method. Corresponds to the JSON property displayName

Returns:

  • (String)


570
571
572
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 570

def display_name
  @display_name
end

#fee_cpmGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::Money

Represents an amount of money with its currency type. Corresponds to the JSON property feeCpm



575
576
577
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 575

def fee_cpm
  @fee_cpm
end

#floor_price_cpmGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::Money

Represents an amount of money with its currency type. Corresponds to the JSON property floorPriceCpm



580
581
582
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 580

def floor_price_cpm
  @floor_price_cpm
end

#nameString

Identifier. The unique resource name for the curated package. Format: curators/accountId/curatedPackages/curatedPackageId` Corresponds to the JSON propertyname`

Returns:

  • (String)


586
587
588
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 586

def name
  @name
end

#stateString

Output only. The state of the curated package. Can be used to filter the response of the curatedPackages.list method. Corresponds to the JSON property state

Returns:

  • (String)


592
593
594
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 592

def state
  @state
end

#targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::PackageTargeting

Targeting criteria for curated and auction packages. Corresponds to the JSON property targeting



597
598
599
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 597

def targeting
  @targeting
end

#update_timeString

Output only. The timestamp when the curated package was last updated. Can be used to filter the response of the curatedPackages.list method. Corresponds to the JSON property updateTime

Returns:

  • (String)


603
604
605
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 603

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



610
611
612
613
614
615
616
617
618
619
620
621
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 610

def update!(**args)
  @access_settings = args[:access_settings] if args.key?(:access_settings)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @fee_cpm = args[:fee_cpm] if args.key?(:fee_cpm)
  @floor_price_cpm = args[:floor_price_cpm] if args.key?(:floor_price_cpm)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @targeting = args[:targeting] if args.key?(:targeting)
  @update_time = args[:update_time] if args.key?(:update_time)
end