Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DataSegment
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DataSegment
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Defines an identifier for a segment of inventory that can be targeted by curators or media planners in the deals or auction packages UI. Curation of inventory is done by curators on external platforms. -- Next ID: 9 --
Instance Attribute Summary collapse
-
#cpm_fee ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Money
Represents an amount of money with its currency type.
-
#create_time ⇒ String
Output only.
-
#millipercent_of_media_fee ⇒ Fixnum
Optional.
-
#name ⇒ String
Immutable.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DataSegment
constructor
A new instance of DataSegment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DataSegment
Returns a new instance of DataSegment.
678 679 680 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 678 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpm_fee ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property cpmFee
647 648 649 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 647 def cpm_fee @cpm_fee end |
#create_time ⇒ String
Output only. Time the data segment was created.
Corresponds to the JSON property createTime
652 653 654 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 652 def create_time @create_time end |
#millipercent_of_media_fee ⇒ Fixnum
Optional. The fee will be charged as a percentage of the impression cost,
represented in millipercent. For example, 1% is represented as 1000.
Corresponds to the JSON property millipercentOfMediaFee
658 659 660 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 658 def millipercent_of_media_fee @millipercent_of_media_fee end |
#name ⇒ String
Immutable. Identifier. The unique identifier for the data segment. Account ID
corresponds to the account ID that created the segment. v1alpha format:
buyers/accountId/dataSegments/curatorDataSegmentIdv1beta format: `
curators/`curatorAccountId`/dataSegments/`curatorDataSegmentId
Corresponds to the JSON property name
666 667 668 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 666 def name @name end |
#state ⇒ String
Output only. The state of the data segment.
Corresponds to the JSON property state
671 672 673 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 671 def state @state end |
#update_time ⇒ String
Output only. Time the data segment was last updated.
Corresponds to the JSON property updateTime
676 677 678 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 676 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
683 684 685 686 687 688 689 690 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 683 def update!(**args) @cpm_fee = args[:cpm_fee] if args.key?(:cpm_fee) @create_time = args[:create_time] if args.key?(:create_time) @millipercent_of_media_fee = args[:millipercent_of_media_fee] if args.key?(:millipercent_of_media_fee) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) end |