Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DataSegment

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Defines an identifier for a segment of inventory that can be targeted by curators or media planners in the deals or auction packages UI. Curation of inventory is done by curators on external platforms.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DataSegment

Returns a new instance of DataSegment.



671
672
673
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 671

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpm_feeGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::Money

Represents an amount of money with its currency type. Corresponds to the JSON property cpmFee



640
641
642
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 640

def cpm_fee
  @cpm_fee
end

#create_timeString

Output only. Time the data segment was created. Corresponds to the JSON property createTime

Returns:

  • (String)


645
646
647
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 645

def create_time
  @create_time
end

#millipercent_of_media_feeFixnum

Optional. The fee will be charged as a percentage of the impression cost, represented in millipercent. For example, 1% is represented as 1000. Corresponds to the JSON property millipercentOfMediaFee

Returns:

  • (Fixnum)


651
652
653
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 651

def millipercent_of_media_fee
  @millipercent_of_media_fee
end

#nameString

Immutable. Identifier. The unique identifier for the data segment. Account ID corresponds to the account ID that created the segment. v1alpha format: buyers/accountId/dataSegments/curatorDataSegmentIdv1beta format: ` curators/`curatorAccountId`/dataSegments/`curatorDataSegmentId Corresponds to the JSON property name

Returns:

  • (String)


659
660
661
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 659

def name
  @name
end

#stateString

Output only. The state of the data segment. Corresponds to the JSON property state

Returns:

  • (String)


664
665
666
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 664

def state
  @state
end

#update_timeString

Output only. Time the data segment was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


669
670
671
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 669

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



676
677
678
679
680
681
682
683
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 676

def update!(**args)
  @cpm_fee = args[:cpm_fee] if args.key?(:cpm_fee)
  @create_time = args[:create_time] if args.key?(:create_time)
  @millipercent_of_media_fee = args[:millipercent_of_media_fee] if args.key?(:millipercent_of_media_fee)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
end