Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DayPart
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DayPart
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Defines targeting for a period of time on a specific week day.
Instance Attribute Summary collapse
-
#day_of_week ⇒ String
Day of week for the period.
-
#end_time ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::TimeOfDay
Represents a time of day.
-
#start_time ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::TimeOfDay
Represents a time of day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DayPart
constructor
A new instance of DayPart.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DayPart
Returns a new instance of DayPart.
709 710 711 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 709 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day_of_week ⇒ String
Day of week for the period.
Corresponds to the JSON property dayOfWeek
693 694 695 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 693 def day_of_week @day_of_week end |
#end_time ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property endTime
700 701 702 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 700 def end_time @end_time end |
#start_time ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::TimeOfDay
Represents a time of day. The date and time zone are either not significant or
are specified elsewhere. An API may choose to allow leap seconds. Related
types are google.type.Date and google.protobuf.Timestamp.
Corresponds to the JSON property startTime
707 708 709 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 707 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
714 715 716 717 718 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 714 def update!(**args) @day_of_week = args[:day_of_week] if args.key?(:day_of_week) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |