Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DayPart

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Defines targeting for a period of time on a specific week day.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DayPart

Returns a new instance of DayPart.



695
696
697
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 695

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#day_of_weekString

Day of week for the period. Corresponds to the JSON property dayOfWeek

Returns:

  • (String)


679
680
681
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 679

def day_of_week
  @day_of_week
end

#end_timeGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property endTime



686
687
688
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 686

def end_time
  @end_time
end

#start_timeGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::TimeOfDay

Represents a time of day. The date and time zone are either not significant or are specified elsewhere. An API may choose to allow leap seconds. Related types are google.type.Date and google.protobuf.Timestamp. Corresponds to the JSON property startTime



693
694
695
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 693

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



700
701
702
703
704
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 700

def update!(**args)
  @day_of_week = args[:day_of_week] if args.key?(:day_of_week)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end