Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Deal
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Deal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
A deal represents a segment of inventory for displaying ads that contains the terms and targeting information that is used for serving as well as the deal stats and status. Note: A proposal may contain multiple deals.
Instance Attribute Summary collapse
-
#billed_buyer ⇒ String
Output only.
-
#buyer ⇒ String
Output only.
-
#buyer_permission_type ⇒ String
Output only.
-
#client ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#creative_requirements ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CreativeRequirements
Message captures data about the creatives in the deal.
-
#deal_type ⇒ String
Output only.
-
#delivery_control ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DeliveryControl
Message contains details about how the deal will be paced.
-
#description ⇒ String
Output only.
-
#display_name ⇒ String
Output only.
-
#eligible_seat_ids ⇒ Array<String>
Output only.
-
#estimated_gross_spend ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Money
Represents an amount of money with its currency type.
-
#flight_end_time ⇒ String
Proposed flight end time of the deal.
-
#flight_start_time ⇒ String
Proposed flight start time of the deal.
-
#media_planner ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::MediaPlanner
Represents a media planner account.
-
#name ⇒ String
Immutable.
-
#preferred_deal_terms ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PreferredDealTerms
Pricing terms for Preferred Deals.
-
#private_auction_terms ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PrivateAuctionTerms
Pricing terms for Private Auctions.
-
#programmatic_guaranteed_terms ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ProgrammaticGuaranteedTerms
Pricing terms for Programmatic Guaranteed Deals.
-
#proposal_revision ⇒ Fixnum
Output only.
-
#publisher_profile ⇒ String
Immutable.
-
#seller_time_zone ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::TimeZone
Represents a time zone from the IANA Time Zone Database.
-
#targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::MarketplaceTargeting
Targeting represents different criteria that can be used to target deals or auction packages.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Deal
constructor
A new instance of Deal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Deal
Returns a new instance of Deal.
936 937 938 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 936 def initialize(**args) update!(**args) end |
Instance Attribute Details
#billed_buyer ⇒ String
Output only. When the client field is populated, this field refers to the
buyer who creates and manages the client buyer and gets billed on behalf of
the client buyer; when the buyer field is populated, this field is the same
value as buyer; when the deal belongs to a media planner account, this field
will be empty. Format : buyers/buyerAccountId`
Corresponds to the JSON propertybilledBuyer`
797 798 799 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 797 def billed_buyer @billed_buyer end |
#buyer ⇒ String
Output only. Refers to a buyer in Real-time Bidding API's Buyer resource.
Format: buyers/buyerAccountId`
Corresponds to the JSON propertybuyer`
803 804 805 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 803 def buyer @buyer end |
#buyer_permission_type ⇒ String
Output only. The buyer permission type of the deal.
Corresponds to the JSON property buyerPermissionType
808 809 810 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 808 def @buyer_permission_type end |
#client ⇒ String
Output only. Refers to a Client. Format: buyers/buyerAccountId/clients/
clientAccountid`
Corresponds to the JSON propertyclient`
814 815 816 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 814 def client @client end |
#create_time ⇒ String
Output only. The time of the deal creation.
Corresponds to the JSON property createTime
819 820 821 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 819 def create_time @create_time end |
#creative_requirements ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CreativeRequirements
Message captures data about the creatives in the deal.
Corresponds to the JSON property creativeRequirements
824 825 826 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 824 def creative_requirements @creative_requirements end |
#deal_type ⇒ String
Output only. Type of deal.
Corresponds to the JSON property dealType
829 830 831 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 829 def deal_type @deal_type end |
#delivery_control ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DeliveryControl
Message contains details about how the deal will be paced.
Corresponds to the JSON property deliveryControl
834 835 836 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 834 def delivery_control @delivery_control end |
#description ⇒ String
Output only. Free text description for the deal terms.
Corresponds to the JSON property description
839 840 841 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 839 def description @description end |
#display_name ⇒ String
Output only. The name of the deal. Maximum length of 255 unicode characters is
allowed. Control characters are not allowed. Buyers cannot update this field.
Note: Not to be confused with name, which is a unique identifier of the deal.
Corresponds to the JSON property displayName
846 847 848 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 846 def display_name @display_name end |
#eligible_seat_ids ⇒ Array<String>
Output only. If set, this field contains the list of DSP specific seat ids set
by media planners that are eligible to transact on this deal. The seat ID is
in the calling DSP's namespace.
Corresponds to the JSON property eligibleSeatIds
853 854 855 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 853 def eligible_seat_ids @eligible_seat_ids end |
#estimated_gross_spend ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property estimatedGrossSpend
858 859 860 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 858 def estimated_gross_spend @estimated_gross_spend end |
#flight_end_time ⇒ String
Proposed flight end time of the deal. This will generally be stored in a
granularity of a second. A value is not necessary for Private Auction deals.
Corresponds to the JSON property flightEndTime
864 865 866 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 864 def flight_end_time @flight_end_time end |
#flight_start_time ⇒ String
Proposed flight start time of the deal. This will generally be stored in the
granularity of one second since deal serving starts at seconds boundary. Any
time specified with more granularity (for example, in milliseconds) will be
truncated towards the start of time in seconds.
Corresponds to the JSON property flightStartTime
872 873 874 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 872 def flight_start_time @flight_start_time end |
#media_planner ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::MediaPlanner
Represents a media planner account.
Corresponds to the JSON property mediaPlanner
877 878 879 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 877 def media_planner @media_planner end |
#name ⇒ String
Immutable. The unique identifier of the deal. Auto-generated by the server
when a deal is created. Format: buyers/accountId/proposals/proposalId/
deals/dealId
Corresponds to the JSON property name
884 885 886 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 884 def name @name end |
#preferred_deal_terms ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PreferredDealTerms
Pricing terms for Preferred Deals.
Corresponds to the JSON property preferredDealTerms
889 890 891 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 889 def preferred_deal_terms @preferred_deal_terms end |
#private_auction_terms ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PrivateAuctionTerms
Pricing terms for Private Auctions.
Corresponds to the JSON property privateAuctionTerms
894 895 896 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 894 def private_auction_terms @private_auction_terms end |
#programmatic_guaranteed_terms ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ProgrammaticGuaranteedTerms
Pricing terms for Programmatic Guaranteed Deals.
Corresponds to the JSON property programmaticGuaranteedTerms
899 900 901 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 899 def programmatic_guaranteed_terms @programmatic_guaranteed_terms end |
#proposal_revision ⇒ Fixnum
Output only. The revision number for the proposal and is the same value as
proposal.proposal_revision. Each update to deal causes the proposal revision
number to auto-increment. The buyer keeps track of the last revision number
they know of and pass it in when making an update. If the head revision number
on the server has since incremented, then an ABORTED error is returned during
the update operation to let the buyer know that a subsequent update was made.
Corresponds to the JSON property proposalRevision
909 910 911 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 909 def proposal_revision @proposal_revision end |
#publisher_profile ⇒ String
Immutable. Reference to the seller on the deal. Format: buyers/
buyerAccountId/publisherProfiles/publisherProfileId`
Corresponds to the JSON propertypublisherProfile`
915 916 917 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 915 def publisher_profile @publisher_profile end |
#seller_time_zone ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::TimeZone
Represents a time zone from the IANA Time Zone Database.
Corresponds to the JSON property sellerTimeZone
921 922 923 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 921 def seller_time_zone @seller_time_zone end |
#targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::MarketplaceTargeting
Targeting represents different criteria that can be used to target deals or
auction packages. For example, they can choose to target inventory only if the
user is in the US. Multiple types of targeting are always applied as a logical
AND, unless noted otherwise.
Corresponds to the JSON property targeting
929 930 931 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 929 def targeting @targeting end |
#update_time ⇒ String
Output only. The time when the deal was last updated.
Corresponds to the JSON property updateTime
934 935 936 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 934 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
941 942 943 944 945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 963 964 965 966 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 941 def update!(**args) @billed_buyer = args[:billed_buyer] if args.key?(:billed_buyer) @buyer = args[:buyer] if args.key?(:buyer) @buyer_permission_type = args[:buyer_permission_type] if args.key?(:buyer_permission_type) @client = args[:client] if args.key?(:client) @create_time = args[:create_time] if args.key?(:create_time) @creative_requirements = args[:creative_requirements] if args.key?(:creative_requirements) @deal_type = args[:deal_type] if args.key?(:deal_type) @delivery_control = args[:delivery_control] if args.key?(:delivery_control) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @eligible_seat_ids = args[:eligible_seat_ids] if args.key?(:eligible_seat_ids) @estimated_gross_spend = args[:estimated_gross_spend] if args.key?(:estimated_gross_spend) @flight_end_time = args[:flight_end_time] if args.key?(:flight_end_time) @flight_start_time = args[:flight_start_time] if args.key?(:flight_start_time) @media_planner = args[:media_planner] if args.key?(:media_planner) @name = args[:name] if args.key?(:name) @preferred_deal_terms = args[:preferred_deal_terms] if args.key?(:preferred_deal_terms) @private_auction_terms = args[:private_auction_terms] if args.key?(:private_auction_terms) @programmatic_guaranteed_terms = args[:programmatic_guaranteed_terms] if args.key?(:programmatic_guaranteed_terms) @proposal_revision = args[:proposal_revision] if args.key?(:proposal_revision) @publisher_profile = args[:publisher_profile] if args.key?(:publisher_profile) @seller_time_zone = args[:seller_time_zone] if args.key?(:seller_time_zone) @targeting = args[:targeting] if args.key?(:targeting) @update_time = args[:update_time] if args.key?(:update_time) end |