Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::FinalizedDeal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

A finalized deal is a snapshot of the deal when both buyer and seller accept the deal. The buyer or seller can update the deal after it's been finalized and renegotiate on the deal targeting, terms and other fields, while at the same time the finalized snapshot of the deal can still be retrieved using this API. The finalized deal contains a copy of the deal as it existed when most recently finalized, as well as fields related to deal serving such as pause/ resume status, RTB metrics, and more.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FinalizedDeal

Returns a new instance of FinalizedDeal.



1121
1122
1123
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1121

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dealGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::Deal

A deal represents a segment of inventory for displaying ads that contains the terms and targeting information that is used for serving as well as the deal stats and status. Note: A proposal may contain multiple deals. Corresponds to the JSON property deal



1091
1092
1093
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1091

def deal
  @deal
end

#deal_pausing_infoGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::DealPausingInfo

Information related to deal pausing. Corresponds to the JSON property dealPausingInfo



1096
1097
1098
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1096

def deal_pausing_info
  @deal_pausing_info
end

#deal_serving_statusString

Serving status of the deal. Corresponds to the JSON property dealServingStatus

Returns:

  • (String)


1101
1102
1103
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1101

def deal_serving_status
  @deal_serving_status
end

#nameString

The resource name of the finalized deal. Format: buyers/accountId/ finalizedDeals/finalizedDealId` Corresponds to the JSON propertyname`

Returns:

  • (String)


1107
1108
1109
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1107

def name
  @name
end

#ready_to_serveBoolean Also known as: ready_to_serve?

Whether the Programmatic Guaranteed deal is ready for serving. Corresponds to the JSON property readyToServe

Returns:

  • (Boolean)


1112
1113
1114
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1112

def ready_to_serve
  @ready_to_serve
end

#rtb_metricsGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::RtbMetrics

Real-time bidding metrics. For what each metric means refer to Report metrics Corresponds to the JSON property rtbMetrics



1119
1120
1121
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1119

def rtb_metrics
  @rtb_metrics
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1126
1127
1128
1129
1130
1131
1132
1133
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1126

def update!(**args)
  @deal = args[:deal] if args.key?(:deal)
  @deal_pausing_info = args[:deal_pausing_info] if args.key?(:deal_pausing_info)
  @deal_serving_status = args[:deal_serving_status] if args.key?(:deal_serving_status)
  @name = args[:name] if args.key?(:name)
  @ready_to_serve = args[:ready_to_serve] if args.key?(:ready_to_serve)
  @rtb_metrics = args[:rtb_metrics] if args.key?(:rtb_metrics)
end