Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::FinalizedDeal
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::FinalizedDeal
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
A finalized deal is a snapshot of the deal when both buyer and seller accept the deal. The buyer or seller can update the deal after it's been finalized and renegotiate on the deal targeting, terms and other fields, while at the same time the finalized snapshot of the deal can still be retrieved using this API. The finalized deal contains a copy of the deal as it existed when most recently finalized, as well as fields related to deal serving such as pause/ resume status, RTB metrics, and more.
Instance Attribute Summary collapse
-
#deal ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Deal
A deal represents a segment of inventory for displaying ads that contains the terms and targeting information that is used for serving as well as the deal stats and status.
-
#deal_pausing_info ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DealPausingInfo
Information related to deal pausing.
-
#deal_serving_status ⇒ String
Serving status of the deal.
-
#name ⇒ String
The resource name of the finalized deal.
-
#ready_to_serve ⇒ Boolean
(also: #ready_to_serve?)
Whether the Programmatic Guaranteed deal is ready for serving.
-
#rtb_metrics ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::RtbMetrics
Real-time bidding metrics.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FinalizedDeal
constructor
A new instance of FinalizedDeal.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FinalizedDeal
Returns a new instance of FinalizedDeal.
1107 1108 1109 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1107 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deal ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Deal
A deal represents a segment of inventory for displaying ads that contains the
terms and targeting information that is used for serving as well as the deal
stats and status. Note: A proposal may contain multiple deals.
Corresponds to the JSON property deal
1077 1078 1079 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1077 def deal @deal end |
#deal_pausing_info ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DealPausingInfo
Information related to deal pausing.
Corresponds to the JSON property dealPausingInfo
1082 1083 1084 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1082 def deal_pausing_info @deal_pausing_info end |
#deal_serving_status ⇒ String
Serving status of the deal.
Corresponds to the JSON property dealServingStatus
1087 1088 1089 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1087 def deal_serving_status @deal_serving_status end |
#name ⇒ String
The resource name of the finalized deal. Format: buyers/accountId/
finalizedDeals/finalizedDealId`
Corresponds to the JSON propertyname`
1093 1094 1095 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1093 def name @name end |
#ready_to_serve ⇒ Boolean Also known as: ready_to_serve?
Whether the Programmatic Guaranteed deal is ready for serving.
Corresponds to the JSON property readyToServe
1098 1099 1100 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1098 def ready_to_serve @ready_to_serve end |
#rtb_metrics ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::RtbMetrics
Real-time bidding metrics. For what each metric means refer to Report metrics
Corresponds to the JSON property rtbMetrics
1105 1106 1107 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1105 def rtb_metrics @rtb_metrics end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1112 1113 1114 1115 1116 1117 1118 1119 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1112 def update!(**args) @deal = args[:deal] if args.key?(:deal) @deal_pausing_info = args[:deal_pausing_info] if args.key?(:deal_pausing_info) @deal_serving_status = args[:deal_serving_status] if args.key?(:deal_serving_status) @name = args[:name] if args.key?(:name) @ready_to_serve = args[:ready_to_serve] if args.key?(:ready_to_serve) @rtb_metrics = args[:rtb_metrics] if args.key?(:rtb_metrics) end |