Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::FrequencyCap

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Message contains details about publisher-set frequency caps of the delivery.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FrequencyCap

Returns a new instance of FrequencyCap.



1173
1174
1175
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_impressionsFixnum

The maximum number of impressions that can be served to a user within the specified time period. Corresponds to the JSON property maxImpressions

Returns:

  • (Fixnum)


1159
1160
1161
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1159

def max_impressions
  @max_impressions
end

#time_unit_typeString

The time unit. Along with num_time_units defines the amount of time over which impressions per user are counted and capped. Corresponds to the JSON property timeUnitType

Returns:

  • (String)


1165
1166
1167
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1165

def time_unit_type
  @time_unit_type
end

#time_units_countFixnum

The amount of time, in the units specified by time_unit_type. Defines the amount of time over which impressions per user are counted and capped. Corresponds to the JSON property timeUnitsCount

Returns:

  • (Fixnum)


1171
1172
1173
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1171

def time_units_count
  @time_units_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1178
1179
1180
1181
1182
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1178

def update!(**args)
  @max_impressions = args[:max_impressions] if args.key?(:max_impressions)
  @time_unit_type = args[:time_unit_type] if args.key?(:time_unit_type)
  @time_units_count = args[:time_units_count] if args.key?(:time_units_count)
end