Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ListClientUsersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Response message for the list method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListClientUsersResponse

Returns a new instance of ListClientUsersResponse.



1272
1273
1274
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1272

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_usersArray<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ClientUser>

The returned list of client users. Corresponds to the JSON property clientUsers



1263
1264
1265
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1263

def client_users
  @client_users
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the ListClientUsersRequest.pageToken field in the subsequent call to the list method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1270
1271
1272
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1270

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1277
1278
1279
1280
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1277

def update!(**args)
  @client_users = args[:client_users] if args.key?(:client_users)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end