Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ListClientsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Response message for the list method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListClientsResponse

Returns a new instance of ListClientsResponse.



1299
1300
1301
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clientsArray<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Client>

The returned list of clients. Corresponds to the JSON property clients



1290
1291
1292
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1290

def clients
  @clients
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the ListClientsRequest.pageToken field in the subsequent call to the list method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1297
1298
1299
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1297

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1304
1305
1306
1307
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1304

def update!(**args)
  @clients = args[:clients] if args.key?(:clients)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end