Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ListClientsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ListClientsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Response message for the list method.
Instance Attribute Summary collapse
-
#clients ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Client>
The returned list of clients.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListClientsResponse
constructor
A new instance of ListClientsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListClientsResponse
Returns a new instance of ListClientsResponse.
1299 1300 1301 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clients ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Client>
The returned list of clients.
Corresponds to the JSON property clients
1290 1291 1292 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1290 def clients @clients end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
ListClientsRequest.pageToken field in the subsequent call to the list method
to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
1297 1298 1299 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1297 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1304 1305 1306 1307 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1304 def update!(**args) @clients = args[:clients] if args.key?(:clients) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |