Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ListCuratedPackagesResponse
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ListCuratedPackagesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Response message for ListCuratedPackages.
Instance Attribute Summary collapse
-
#curated_packages ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CuratedPackage>
The list of curated packages.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCuratedPackagesResponse
constructor
A new instance of ListCuratedPackagesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCuratedPackagesResponse
Returns a new instance of ListCuratedPackagesResponse.
1341 1342 1343 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#curated_packages ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CuratedPackage>
The list of curated packages.
Corresponds to the JSON property curatedPackages
1331 1332 1333 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1331 def curated_packages @curated_packages end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
ListCuratedPackagesRequest.pageToken field in the subsequent call to
ListCuratedPackages method to retrieve the next page of results. If empty,
then there are no more results.
Corresponds to the JSON property nextPageToken
1339 1340 1341 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1339 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1346 1347 1348 1349 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1346 def update!(**args) @curated_packages = args[:curated_packages] if args.key?(:curated_packages) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |