Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ListDataSegmentsResponse
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ListDataSegmentsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Response message for listing data segments.
Instance Attribute Summary collapse
-
#data_segments ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DataSegment>
The list of data segments.
-
#next_page_token ⇒ String
Continuation token for fetching the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListDataSegmentsResponse
constructor
A new instance of ListDataSegmentsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListDataSegmentsResponse
Returns a new instance of ListDataSegmentsResponse.
1354 1355 1356 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1354 def initialize(**args) update!(**args) end |
Instance Attribute Details
#data_segments ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DataSegment>
The list of data segments.
Corresponds to the JSON property dataSegments
1345 1346 1347 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1345 def data_segments @data_segments end |
#next_page_token ⇒ String
Continuation token for fetching the next page of results. Pass this value in
the ListDataSegmentsRequest.pageToken field in the subsequent call to the
ListDataSegments method to retrieve the next page of results.
Corresponds to the JSON property nextPageToken
1352 1353 1354 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1352 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1359 1360 1361 1362 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1359 def update!(**args) @data_segments = args[:data_segments] if args.key?(:data_segments) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |