Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ListMediaPlannersResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

A response containing media planner account information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMediaPlannersResponse

Returns a new instance of ListMediaPlannersResponse.



1431
1432
1433
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#media_plannersArray<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::MediaPlanner>

List of media planners. Corresponds to the JSON property mediaPlanners



1422
1423
1424
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1422

def media_planners
  @media_planners
end

#next_page_tokenString

A token which can be passed to a subsequent call to the ListMediaPlanners method to retrieve the next page of results in ListMediaPlannersRequest. pageToken. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


1429
1430
1431
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1429

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1436
1437
1438
1439
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1436

def update!(**args)
  @media_planners = args[:media_planners] if args.key?(:media_planners)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end