Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::MarketplaceTargeting
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::MarketplaceTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Targeting represents different criteria that can be used to target deals or auction packages. For example, they can choose to target inventory only if the user is in the US. Multiple types of targeting are always applied as a logical AND, unless noted otherwise.
Instance Attribute Summary collapse
-
#daypart_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DayPartTargeting
Represents Daypart targeting.
-
#excluded_sensitive_category_ids ⇒ Array<Fixnum>
Output only.
-
#geo_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
-
#inventory_size_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::InventorySizeTargeting
Represents the size of an ad unit that can be targeted on a bid request.
-
#inventory_type_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::InventoryTypeTargeting
Targeting of the inventory types a bid request can originate from.
-
#placement_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PlacementTargeting
Represents targeting about where the ads can appear, for example, certain sites or mobile applications.
-
#technology_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::TechnologyTargeting
Represents targeting about various types of technology.
-
#user_list_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
-
#vertical_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
-
#video_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::VideoTargeting
Represents targeting information about video.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MarketplaceTargeting
constructor
A new instance of MarketplaceTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MarketplaceTargeting
Returns a new instance of MarketplaceTargeting.
1580 1581 1582 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1580 def initialize(**args) update!(**args) end |
Instance Attribute Details
#daypart_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::DayPartTargeting
Represents Daypart targeting.
Corresponds to the JSON property daypartTargeting
1523 1524 1525 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1523 def daypart_targeting @daypart_targeting end |
#excluded_sensitive_category_ids ⇒ Array<Fixnum>
Output only. The sensitive content category label IDs excluded. Refer to this
file https://storage.googleapis.com/adx-rtb-dictionaries/content-labels.txt
for category IDs.
Corresponds to the JSON property excludedSensitiveCategoryIds
1530 1531 1532 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1530 def excluded_sensitive_category_ids @excluded_sensitive_category_ids end |
#geo_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property geoTargeting
1537 1538 1539 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1537 def geo_targeting @geo_targeting end |
#inventory_size_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::InventorySizeTargeting
Represents the size of an ad unit that can be targeted on a bid request.
Corresponds to the JSON property inventorySizeTargeting
1542 1543 1544 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1542 def inventory_size_targeting @inventory_size_targeting end |
#inventory_type_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::InventoryTypeTargeting
Targeting of the inventory types a bid request can originate from.
Corresponds to the JSON property inventoryTypeTargeting
1547 1548 1549 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1547 def inventory_type_targeting @inventory_type_targeting end |
#placement_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PlacementTargeting
Represents targeting about where the ads can appear, for example, certain
sites or mobile applications. Different placement targeting types will be
logically OR'ed.
Corresponds to the JSON property placementTargeting
1554 1555 1556 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1554 def placement_targeting @placement_targeting end |
#technology_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::TechnologyTargeting
Represents targeting about various types of technology.
Corresponds to the JSON property technologyTargeting
1559 1560 1561 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1559 def technology_targeting @technology_targeting end |
#user_list_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property userListTargeting
1566 1567 1568 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1566 def user_list_targeting @user_list_targeting end |
#vertical_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property verticalTargeting
1573 1574 1575 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1573 def vertical_targeting @vertical_targeting end |
#video_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::VideoTargeting
Represents targeting information about video.
Corresponds to the JSON property videoTargeting
1578 1579 1580 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1578 def video_targeting @video_targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1585 1586 1587 1588 1589 1590 1591 1592 1593 1594 1595 1596 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1585 def update!(**args) @daypart_targeting = args[:daypart_targeting] if args.key?(:daypart_targeting) @excluded_sensitive_category_ids = args[:excluded_sensitive_category_ids] if args.key?(:excluded_sensitive_category_ids) @geo_targeting = args[:geo_targeting] if args.key?(:geo_targeting) @inventory_size_targeting = args[:inventory_size_targeting] if args.key?(:inventory_size_targeting) @inventory_type_targeting = args[:inventory_type_targeting] if args.key?(:inventory_type_targeting) @placement_targeting = args[:placement_targeting] if args.key?(:placement_targeting) @technology_targeting = args[:technology_targeting] if args.key?(:technology_targeting) @user_list_targeting = args[:user_list_targeting] if args.key?(:user_list_targeting) @vertical_targeting = args[:vertical_targeting] if args.key?(:vertical_targeting) @video_targeting = args[:video_targeting] if args.key?(:video_targeting) end |