Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Money

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Represents an amount of money with its currency type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Money

Returns a new instance of Money.



1681
1682
1683
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#currency_codeString

The three-letter currency code defined in ISO 4217. Corresponds to the JSON property currencyCode

Returns:

  • (String)


1664
1665
1666
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1664

def currency_code
  @currency_code
end

#nanosFixnum

Number of nano (10^-9) units of the amount. The value must be between -999,999, 999 and +999,999,999 inclusive. If units is positive, nanos must be positive or zero. If units is zero, nanos can be positive, zero, or negative. If units is negative, nanos must be negative or zero. For example $-1.75 is represented as units=-1 and nanos=-750,000,000. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


1673
1674
1675
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1673

def nanos
  @nanos
end

#unitsFixnum

The whole units of the amount. For example if currencyCode is "USD", then 1 unit is one US dollar. Corresponds to the JSON property units

Returns:

  • (Fixnum)


1679
1680
1681
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1679

def units
  @units
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1686
1687
1688
1689
1690
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1686

def update!(**args)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @nanos = args[:nanos] if args.key?(:nanos)
  @units = args[:units] if args.key?(:units)
end