Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PackageTargeting
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PackageTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Targeting criteria for curated and auction packages.
Instance Attribute Summary collapse
-
#geo_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
-
#included_accelerated_mobile_page_type ⇒ String
Optional.
-
#included_ad_sizes ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::AdSize>
Optional.
-
#included_authorized_seller_statuses ⇒ Array<String>
Optional.
-
#included_creative_format ⇒ String
Optional.
-
#included_data_segments ⇒ Array<String>
Optional.
-
#included_device_types ⇒ Array<String>
Optional.
-
#included_environment ⇒ String
Optional.
-
#included_native_inventory_types ⇒ Array<String>
Optional.
-
#included_open_measurement_types ⇒ Array<String>
Optional.
-
#included_restricted_categories ⇒ Array<String>
Optional.
-
#included_rewarded_type ⇒ String
Optional.
-
#language_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::StringTargetingDimension
Generic targeting with string values.
-
#minimum_predicted_click_through_rate_percentage_millis ⇒ Fixnum
Optional.
-
#minimum_predicted_viewability_percentage ⇒ Fixnum
Optional.
-
#placement_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PackagePlacementTargeting
Represents targeting about where the ads can appear, for example, certain sites or mobile applications.
-
#publisher_provided_signals_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PackagePublisherProvidedSignalsTargeting
Represents targeting about publisher provided signals.
-
#publisher_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::StringTargetingDimension
Generic targeting with string values.
-
#vertical_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
-
#video_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PackageVideoTargeting
Video specific targeting criteria.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageTargeting
constructor
A new instance of PackageTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageTargeting
Returns a new instance of PackageTargeting.
1961 1962 1963 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1961 def initialize(**args) update!(**args) end |
Instance Attribute Details
#geo_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property geoTargeting
1837 1838 1839 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1837 def geo_targeting @geo_targeting end |
#included_accelerated_mobile_page_type ⇒ String
Optional. The targeted accelerated mobile page type. If unset, inventory will
be targeted regardless of AMP status.
Corresponds to the JSON property includedAcceleratedMobilePageType
1843 1844 1845 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1843 def included_accelerated_mobile_page_type @included_accelerated_mobile_page_type end |
#included_ad_sizes ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::AdSize>
Optional. The list of ad sizes to target. If unset, inventory will be targeted
regardless of ad size. Curated packages supports PIXEL and INTERSTITIAL ad
sizes.
Corresponds to the JSON property includedAdSizes
1850 1851 1852 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1850 def included_ad_sizes @included_ad_sizes end |
#included_authorized_seller_statuses ⇒ Array<String>
Optional. The included list of targeted authorized seller statuses. If empty,
inventory will be targeted regardless of seller status.
Corresponds to the JSON property includedAuthorizedSellerStatuses
1856 1857 1858 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1856 def @included_authorized_seller_statuses end |
#included_creative_format ⇒ String
Optional. The creative format to target. If unset, all creative markup types
are targeted.
Corresponds to the JSON property includedCreativeFormat
1862 1863 1864 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1862 def included_creative_format @included_creative_format end |
#included_data_segments ⇒ Array<String>
Optional. The active data segments to be targeted. If unset, inventory will be
targeted regardless of data segments. Format: curators/account_id/
dataSegments/data_segment_id`
Corresponds to the JSON propertyincludedDataSegments`
1869 1870 1871 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1869 def included_data_segments @included_data_segments end |
#included_device_types ⇒ Array<String>
Optional. The list of included device types to target. If empty, all device
types are targeted.
Corresponds to the JSON property includedDeviceTypes
1875 1876 1877 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1875 def included_device_types @included_device_types end |
#included_environment ⇒ String
Optional. The environment to target. If unspecified, all environments are
targeted.
Corresponds to the JSON property includedEnvironment
1881 1882 1883 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1881 def included_environment @included_environment end |
#included_native_inventory_types ⇒ Array<String>
Optional. The targeted native inventory types. If empty, inventory will be
targeted regardless of native inventory type.
Corresponds to the JSON property includedNativeInventoryTypes
1887 1888 1889 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1887 def included_native_inventory_types @included_native_inventory_types end |
#included_open_measurement_types ⇒ Array<String>
Optional. The list of targeted open measurement types. If empty, inventory
will be targeted regardless of Open Measurement support.
Corresponds to the JSON property includedOpenMeasurementTypes
1893 1894 1895 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1893 def included_open_measurement_types @included_open_measurement_types end |
#included_restricted_categories ⇒ Array<String>
Optional. The list of targeted restricted categories. If empty, inventory will
be targeted regardless of restricted categories.
Corresponds to the JSON property includedRestrictedCategories
1899 1900 1901 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1899 def included_restricted_categories @included_restricted_categories end |
#included_rewarded_type ⇒ String
Optional. The targeted rewarded type. If unset, inventory will be targeted
regardless of rewarded type.
Corresponds to the JSON property includedRewardedType
1905 1906 1907 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1905 def included_rewarded_type @included_rewarded_type end |
#language_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::StringTargetingDimension
Generic targeting with string values.
Corresponds to the JSON property languageTargeting
1910 1911 1912 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1910 def language_targeting @language_targeting end |
#minimum_predicted_click_through_rate_percentage_millis ⇒ Fixnum
Optional. The targeted minimum predicted click through rate, ranging in values
10, 10000. A value of 50 means that the configuration will
only match adslots for which we predict at least 0.05% click through rate. An
unset value indicates inventory will be targeted regardless of predicted click
through rate.
Corresponds to the JSON property minimumPredictedClickThroughRatePercentageMillis
1919 1920 1921 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1919 def minimum_predicted_click_through_rate_percentage_millis @minimum_predicted_click_through_rate_percentage_millis end |
#minimum_predicted_viewability_percentage ⇒ Fixnum
Optional. The targeted minimum predicted viewability percentage. This value
must be a multiple of 10 between 10 and 90 (inclusive). For example, 10 is
valid, but 0, 15, and 100 are not. A value of 10 means that the configuration
will only match adslots for which we predict at least 10% viewability. An
unset value indicates inventory will be targeted regardless of predicted
viewability.
Corresponds to the JSON property minimumPredictedViewabilityPercentage
1929 1930 1931 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1929 def minimum_predicted_viewability_percentage @minimum_predicted_viewability_percentage end |
#placement_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PackagePlacementTargeting
Represents targeting about where the ads can appear, for example, certain
sites or mobile applications. Different placement targeting types will be
logically OR'ed.
Corresponds to the JSON property placementTargeting
1936 1937 1938 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1936 def placement_targeting @placement_targeting end |
#publisher_provided_signals_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PackagePublisherProvidedSignalsTargeting
Represents targeting about publisher provided signals. Different publisher
provided signals types will be logically OR'ed.
Corresponds to the JSON property publisherProvidedSignalsTargeting
1942 1943 1944 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1942 def publisher_provided_signals_targeting @publisher_provided_signals_targeting end |
#publisher_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::StringTargetingDimension
Generic targeting with string values.
Corresponds to the JSON property publisherTargeting
1947 1948 1949 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1947 def publisher_targeting @publisher_targeting end |
#vertical_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property verticalTargeting
1954 1955 1956 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1954 def vertical_targeting @vertical_targeting end |
#video_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PackageVideoTargeting
Video specific targeting criteria.
Corresponds to the JSON property videoTargeting
1959 1960 1961 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1959 def video_targeting @video_targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1966 1967 1968 1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 1981 1982 1983 1984 1985 1986 1987 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1966 def update!(**args) @geo_targeting = args[:geo_targeting] if args.key?(:geo_targeting) @included_accelerated_mobile_page_type = args[:included_accelerated_mobile_page_type] if args.key?(:included_accelerated_mobile_page_type) @included_ad_sizes = args[:included_ad_sizes] if args.key?(:included_ad_sizes) @included_authorized_seller_statuses = args[:included_authorized_seller_statuses] if args.key?(:included_authorized_seller_statuses) @included_creative_format = args[:included_creative_format] if args.key?(:included_creative_format) @included_data_segments = args[:included_data_segments] if args.key?(:included_data_segments) @included_device_types = args[:included_device_types] if args.key?(:included_device_types) @included_environment = args[:included_environment] if args.key?(:included_environment) @included_native_inventory_types = args[:included_native_inventory_types] if args.key?(:included_native_inventory_types) @included_open_measurement_types = args[:included_open_measurement_types] if args.key?(:included_open_measurement_types) @included_restricted_categories = args[:included_restricted_categories] if args.key?(:included_restricted_categories) @included_rewarded_type = args[:included_rewarded_type] if args.key?(:included_rewarded_type) @language_targeting = args[:language_targeting] if args.key?(:language_targeting) @minimum_predicted_click_through_rate_percentage_millis = args[:minimum_predicted_click_through_rate_percentage_millis] if args.key?(:minimum_predicted_click_through_rate_percentage_millis) @minimum_predicted_viewability_percentage = args[:minimum_predicted_viewability_percentage] if args.key?(:minimum_predicted_viewability_percentage) @placement_targeting = args[:placement_targeting] if args.key?(:placement_targeting) @publisher_provided_signals_targeting = args[:publisher_provided_signals_targeting] if args.key?(:publisher_provided_signals_targeting) @publisher_targeting = args[:publisher_targeting] if args.key?(:publisher_targeting) @vertical_targeting = args[:vertical_targeting] if args.key?(:vertical_targeting) @video_targeting = args[:video_targeting] if args.key?(:video_targeting) end |