Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PackageTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Targeting criteria for curated and auction packages.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PackageTargeting

Returns a new instance of PackageTargeting.



1940
1941
1942
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1940

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#geo_targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting

Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs. This cannot be filtered using list filter syntax. Corresponds to the JSON property geoTargeting



1816
1817
1818
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1816

def geo_targeting
  @geo_targeting
end

#included_accelerated_mobile_page_typeString

Optional. The targeted accelerated mobile page type. If unset, inventory will be targeted regardless of AMP status. Corresponds to the JSON property includedAcceleratedMobilePageType

Returns:

  • (String)


1822
1823
1824
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1822

def included_accelerated_mobile_page_type
  @included_accelerated_mobile_page_type
end

#included_ad_sizesArray<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::AdSize>

Optional. The list of ad sizes to target. If unset, inventory will be targeted regardless of ad size. Curated packages supports PIXEL and INTERSTITIAL ad sizes. Corresponds to the JSON property includedAdSizes



1829
1830
1831
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1829

def included_ad_sizes
  @included_ad_sizes
end

#included_authorized_seller_statusesArray<String>

Optional. The included list of targeted authorized seller statuses. If empty, inventory will be targeted regardless of seller status. Corresponds to the JSON property includedAuthorizedSellerStatuses

Returns:

  • (Array<String>)


1835
1836
1837
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1835

def included_authorized_seller_statuses
  @included_authorized_seller_statuses
end

#included_creative_formatString

Optional. The creative format to target. If unset, all creative markup types are targeted. Corresponds to the JSON property includedCreativeFormat

Returns:

  • (String)


1841
1842
1843
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1841

def included_creative_format
  @included_creative_format
end

#included_data_segmentsArray<String>

Optional. The active data segments to be targeted. If unset, inventory will be targeted regardless of data segments. Format: curators/account_id/ dataSegments/data_segment_id` Corresponds to the JSON propertyincludedDataSegments`

Returns:

  • (Array<String>)


1848
1849
1850
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1848

def included_data_segments
  @included_data_segments
end

#included_device_typesArray<String>

Optional. The list of included device types to target. If empty, all device types are targeted. Corresponds to the JSON property includedDeviceTypes

Returns:

  • (Array<String>)


1854
1855
1856
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1854

def included_device_types
  @included_device_types
end

#included_environmentString

Optional. The environment to target. If unspecified, all environments are targeted. Corresponds to the JSON property includedEnvironment

Returns:

  • (String)


1860
1861
1862
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1860

def included_environment
  @included_environment
end

#included_native_inventory_typesArray<String>

Optional. The targeted native inventory types. If empty, inventory will be targeted regardless of native inventory type. Corresponds to the JSON property includedNativeInventoryTypes

Returns:

  • (Array<String>)


1866
1867
1868
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1866

def included_native_inventory_types
  @included_native_inventory_types
end

#included_open_measurement_typesArray<String>

Optional. The list of targeted open measurement types. If empty, inventory will be targeted regardless of Open Measurement support. Corresponds to the JSON property includedOpenMeasurementTypes

Returns:

  • (Array<String>)


1872
1873
1874
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1872

def included_open_measurement_types
  @included_open_measurement_types
end

#included_restricted_categoriesArray<String>

Optional. The list of targeted restricted categories. If empty, inventory will be targeted regardless of restricted categories. Corresponds to the JSON property includedRestrictedCategories

Returns:

  • (Array<String>)


1878
1879
1880
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1878

def included_restricted_categories
  @included_restricted_categories
end

#included_rewarded_typeString

Optional. The targeted rewarded type. If unset, inventory will be targeted regardless of rewarded type. Corresponds to the JSON property includedRewardedType

Returns:

  • (String)


1884
1885
1886
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1884

def included_rewarded_type
  @included_rewarded_type
end

#language_targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::StringTargetingDimension

Generic targeting with string values. Corresponds to the JSON property languageTargeting



1889
1890
1891
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1889

def language_targeting
  @language_targeting
end

#minimum_predicted_click_through_rate_percentage_millisFixnum

Optional. The targeted minimum predicted click through rate, ranging in values 10, 10000. A value of 50 means that the configuration will only match adslots for which we predict at least 0.05% click through rate. An unset value indicates inventory will be targeted regardless of predicted click through rate. Corresponds to the JSON property minimumPredictedClickThroughRatePercentageMillis

Returns:

  • (Fixnum)


1898
1899
1900
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1898

def minimum_predicted_click_through_rate_percentage_millis
  @minimum_predicted_click_through_rate_percentage_millis
end

#minimum_predicted_viewability_percentageFixnum

Optional. The targeted minimum predicted viewability percentage. This value must be a multiple of 10 between 10 and 90 (inclusive). For example, 10 is valid, but 0, 15, and 100 are not. A value of 10 means that the configuration will only match adslots for which we predict at least 10% viewability. An unset value indicates inventory will be targeted regardless of predicted viewability. Corresponds to the JSON property minimumPredictedViewabilityPercentage

Returns:

  • (Fixnum)


1908
1909
1910
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1908

def minimum_predicted_viewability_percentage
  @minimum_predicted_viewability_percentage
end

#placement_targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::PackagePlacementTargeting

Represents targeting about where the ads can appear, for example, certain sites or mobile applications. Different placement targeting types will be logically OR'ed. Corresponds to the JSON property placementTargeting



1915
1916
1917
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1915

def placement_targeting
  @placement_targeting
end

#publisher_provided_signals_targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::PackagePublisherProvidedSignalsTargeting

Represents targeting about publisher provided signals. Different publisher provided signals types will be logically OR'ed. Corresponds to the JSON property publisherProvidedSignalsTargeting



1921
1922
1923
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1921

def publisher_provided_signals_targeting
  @publisher_provided_signals_targeting
end

#publisher_targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::StringTargetingDimension

Generic targeting with string values. Corresponds to the JSON property publisherTargeting



1926
1927
1928
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1926

def publisher_targeting
  @publisher_targeting
end

#vertical_targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting

Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs. This cannot be filtered using list filter syntax. Corresponds to the JSON property verticalTargeting



1933
1934
1935
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1933

def vertical_targeting
  @vertical_targeting
end

#video_targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::PackageVideoTargeting

Video specific targeting criteria. Corresponds to the JSON property videoTargeting



1938
1939
1940
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1938

def video_targeting
  @video_targeting
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1945
1946
1947
1948
1949
1950
1951
1952
1953
1954
1955
1956
1957
1958
1959
1960
1961
1962
1963
1964
1965
1966
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1945

def update!(**args)
  @geo_targeting = args[:geo_targeting] if args.key?(:geo_targeting)
  @included_accelerated_mobile_page_type = args[:included_accelerated_mobile_page_type] if args.key?(:included_accelerated_mobile_page_type)
  @included_ad_sizes = args[:included_ad_sizes] if args.key?(:included_ad_sizes)
  @included_authorized_seller_statuses = args[:included_authorized_seller_statuses] if args.key?(:included_authorized_seller_statuses)
  @included_creative_format = args[:included_creative_format] if args.key?(:included_creative_format)
  @included_data_segments = args[:included_data_segments] if args.key?(:included_data_segments)
  @included_device_types = args[:included_device_types] if args.key?(:included_device_types)
  @included_environment = args[:included_environment] if args.key?(:included_environment)
  @included_native_inventory_types = args[:included_native_inventory_types] if args.key?(:included_native_inventory_types)
  @included_open_measurement_types = args[:included_open_measurement_types] if args.key?(:included_open_measurement_types)
  @included_restricted_categories = args[:included_restricted_categories] if args.key?(:included_restricted_categories)
  @included_rewarded_type = args[:included_rewarded_type] if args.key?(:included_rewarded_type)
  @language_targeting = args[:language_targeting] if args.key?(:language_targeting)
  @minimum_predicted_click_through_rate_percentage_millis = args[:minimum_predicted_click_through_rate_percentage_millis] if args.key?(:minimum_predicted_click_through_rate_percentage_millis)
  @minimum_predicted_viewability_percentage = args[:minimum_predicted_viewability_percentage] if args.key?(:minimum_predicted_viewability_percentage)
  @placement_targeting = args[:placement_targeting] if args.key?(:placement_targeting)
  @publisher_provided_signals_targeting = args[:publisher_provided_signals_targeting] if args.key?(:publisher_provided_signals_targeting)
  @publisher_targeting = args[:publisher_targeting] if args.key?(:publisher_targeting)
  @vertical_targeting = args[:vertical_targeting] if args.key?(:vertical_targeting)
  @video_targeting = args[:video_targeting] if args.key?(:video_targeting)
end