Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PackageVideoTargeting
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PackageVideoTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Video specific targeting criteria.
Instance Attribute Summary collapse
-
#included_content_delivery_method ⇒ String
Optional.
-
#included_maximum_ad_duration_targeting ⇒ String
Optional.
-
#included_mime_types ⇒ Array<String>
Optional.
-
#included_playback_methods ⇒ Array<String>
Optional.
-
#included_player_size_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::VideoPlayerSizeTargeting
Represents the size of the video player that can be targeted.
-
#included_position_types ⇒ Array<String>
Optional.
-
#minimum_predicted_completion_rate_percentage ⇒ Fixnum
Optional.
-
#plcmt_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::VideoPlcmtTargeting
Defines targeting criteria based on the video placement type, often corresponding to the IAB OpenRTB 'plcmt' field.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PackageVideoTargeting
constructor
A new instance of PackageVideoTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PackageVideoTargeting
Returns a new instance of PackageVideoTargeting.
2026 2027 2028 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2026 def initialize(**args) update!(**args) end |
Instance Attribute Details
#included_content_delivery_method ⇒ String
Optional. The targeted video delivery method. If unset, inventory will be
targeted regardless of video delivery method.
Corresponds to the JSON property includedContentDeliveryMethod
1977 1978 1979 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1977 def included_content_delivery_method @included_content_delivery_method end |
#included_maximum_ad_duration_targeting ⇒ String
Optional. The targeted maximum video ad duration. If unset, inventory will be
targeted regardless of maximum video ad duration.
Corresponds to the JSON property includedMaximumAdDurationTargeting
1983 1984 1985 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1983 def included_maximum_ad_duration_targeting @included_maximum_ad_duration_targeting end |
#included_mime_types ⇒ Array<String>
Optional. The list of targeted video mime types using the IANA published MIME
type strings (https://www.iana.org/assignments/media-types/media-types.xhtml).
If empty, inventory will be targeted regardless of video mime type.
Corresponds to the JSON property includedMimeTypes
1990 1991 1992 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1990 def included_mime_types @included_mime_types end |
#included_playback_methods ⇒ Array<String>
Optional. The list of targeted video playback methods. If empty, inventory
will be targeted regardless of video playback method.
Corresponds to the JSON property includedPlaybackMethods
1996 1997 1998 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 1996 def included_playback_methods @included_playback_methods end |
#included_player_size_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::VideoPlayerSizeTargeting
Represents the size of the video player that can be targeted. Both width and
height are required to be set to non-zero values.
Corresponds to the JSON property includedPlayerSizeTargeting
2002 2003 2004 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2002 def included_player_size_targeting @included_player_size_targeting end |
#included_position_types ⇒ Array<String>
Optional. The targeted video ad position types. If empty, inventory will be
targeted regardless of video ad position type.
Corresponds to the JSON property includedPositionTypes
2008 2009 2010 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2008 def included_position_types @included_position_types end |
#minimum_predicted_completion_rate_percentage ⇒ Fixnum
Optional. The targeted minimum predicted completion rate percentage. This
value must be a multiple of 10 between 10 and 90 (inclusive). For example, 10
is valid, but 0, 15, and 100 are not. A value of 10 means that the
configuration will only match adslots for which we predict at least 10%
completion rate. An unset value indicates inventory will be targeted
regardless of predicted completion rate.
Corresponds to the JSON property minimumPredictedCompletionRatePercentage
2018 2019 2020 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2018 def minimum_predicted_completion_rate_percentage @minimum_predicted_completion_rate_percentage end |
#plcmt_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::VideoPlcmtTargeting
Defines targeting criteria based on the video placement type, often
corresponding to the IAB OpenRTB 'plcmt' field.
Corresponds to the JSON property plcmtTargeting
2024 2025 2026 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2024 def plcmt_targeting @plcmt_targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2031 2032 2033 2034 2035 2036 2037 2038 2039 2040 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2031 def update!(**args) @included_content_delivery_method = args[:included_content_delivery_method] if args.key?(:included_content_delivery_method) @included_maximum_ad_duration_targeting = args[:included_maximum_ad_duration_targeting] if args.key?(:included_maximum_ad_duration_targeting) @included_mime_types = args[:included_mime_types] if args.key?(:included_mime_types) @included_playback_methods = args[:included_playback_methods] if args.key?(:included_playback_methods) @included_player_size_targeting = args[:included_player_size_targeting] if args.key?(:included_player_size_targeting) @included_position_types = args[:included_position_types] if args.key?(:included_position_types) @minimum_predicted_completion_rate_percentage = args[:minimum_predicted_completion_rate_percentage] if args.key?(:minimum_predicted_completion_rate_percentage) @plcmt_targeting = args[:plcmt_targeting] if args.key?(:plcmt_targeting) end |