Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Price
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Price
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Represents a price and a pricing type for a deal.
Instance Attribute Summary collapse
-
#amount ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Money
Represents an amount of money with its currency type.
-
#type ⇒ String
The pricing type for the deal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Price
constructor
A new instance of Price.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Price
Returns a new instance of Price.
2139 2140 2141 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2139 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amount ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property amount
2132 2133 2134 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2132 def amount @amount end |
#type ⇒ String
The pricing type for the deal.
Corresponds to the JSON property type
2137 2138 2139 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2137 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2144 2145 2146 2147 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2144 def update!(**args) @amount = args[:amount] if args.key?(:amount) @type = args[:type] if args.key?(:type) end |