Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ProgrammaticGuaranteedTerms
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::ProgrammaticGuaranteedTerms
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Pricing terms for Programmatic Guaranteed Deals.
Instance Attribute Summary collapse
-
#fixed_price ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Price
Represents a price and a pricing type for a deal.
-
#guaranteed_looks ⇒ Fixnum
Count of guaranteed looks.
-
#impression_cap ⇒ Fixnum
The lifetime impression cap for CPM Sponsorship deals.
-
#minimum_daily_looks ⇒ Fixnum
Daily minimum looks for CPD deal types.
-
#percent_share_of_voice ⇒ Fixnum
For sponsorship deals, this is the percentage of the seller's eligible impressions that the deal will serve until the cap is reached.
-
#reservation_type ⇒ String
The reservation type for a Programmatic Guaranteed deal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProgrammaticGuaranteedTerms
constructor
A new instance of ProgrammaticGuaranteedTerms.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProgrammaticGuaranteedTerms
Returns a new instance of ProgrammaticGuaranteedTerms.
2224 2225 2226 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fixed_price ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Price
Represents a price and a pricing type for a deal.
Corresponds to the JSON property fixedPrice
2190 2191 2192 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2190 def fixed_price @fixed_price end |
#guaranteed_looks ⇒ Fixnum
Count of guaranteed looks. For CPD deals, buyer changes to guaranteed_looks
will be ignored.
Corresponds to the JSON property guaranteedLooks
2196 2197 2198 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2196 def guaranteed_looks @guaranteed_looks end |
#impression_cap ⇒ Fixnum
The lifetime impression cap for CPM Sponsorship deals. Deal will stop serving
when cap is reached.
Corresponds to the JSON property impressionCap
2202 2203 2204 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2202 def impression_cap @impression_cap end |
#minimum_daily_looks ⇒ Fixnum
Daily minimum looks for CPD deal types. For CPD deals, buyer should negotiate
on this field instead of guaranteed_looks.
Corresponds to the JSON property minimumDailyLooks
2208 2209 2210 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2208 def minimum_daily_looks @minimum_daily_looks end |
#percent_share_of_voice ⇒ Fixnum
For sponsorship deals, this is the percentage of the seller's eligible
impressions that the deal will serve until the cap is reached. Valid value is
within range 0~100.
Corresponds to the JSON property percentShareOfVoice
2215 2216 2217 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2215 def percent_share_of_voice @percent_share_of_voice end |
#reservation_type ⇒ String
The reservation type for a Programmatic Guaranteed deal. This indicates
whether the number of impressions is fixed, or a percent of available
impressions. If not specified, the default reservation type is STANDARD.
Corresponds to the JSON property reservationType
2222 2223 2224 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2222 def reservation_type @reservation_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2229 2230 2231 2232 2233 2234 2235 2236 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2229 def update!(**args) @fixed_price = args[:fixed_price] if args.key?(:fixed_price) @guaranteed_looks = args[:guaranteed_looks] if args.key?(:guaranteed_looks) @impression_cap = args[:impression_cap] if args.key?(:impression_cap) @minimum_daily_looks = args[:minimum_daily_looks] if args.key?(:minimum_daily_looks) @percent_share_of_voice = args[:percent_share_of_voice] if args.key?(:percent_share_of_voice) @reservation_type = args[:reservation_type] if args.key?(:reservation_type) end |