Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Proposal

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Represents a proposal in the Marketplace. A proposal is the unit of negotiation between a seller and a buyer.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Proposal

Returns a new instance of Proposal.



2377
2378
2379
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2377

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#billed_buyerString

Output only. When the client field is populated, this field refers to the buyer who creates and manages the client buyer and gets billed on behalf of the client buyer; when the buyer field is populated, this field is the same value as buyer. Format : buyers/buyerAccountId` Corresponds to the JSON propertybilledBuyer`

Returns:

  • (String)


2264
2265
2266
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2264

def billed_buyer
  @billed_buyer
end

#buyerString

Output only. Refers to a buyer in The Realtime-bidding API. Format: buyers/ buyerAccountId` Corresponds to the JSON propertybuyer`

Returns:

  • (String)


2270
2271
2272
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2270

def buyer
  @buyer
end

#buyer_contactsArray<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Contact>

Contact information for the buyer. Corresponds to the JSON property buyerContacts



2275
2276
2277
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2275

def buyer_contacts
  @buyer_contacts
end

#buyer_private_dataGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::PrivateData

Buyers are allowed to store certain types of private data in a proposal. Corresponds to the JSON property buyerPrivateData



2280
2281
2282
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2280

def buyer_private_data
  @buyer_private_data
end

#clientString

Output only. Refers to a Client. Format: buyers/buyerAccountId/clients/ clientAccountid` Corresponds to the JSON propertyclient`

Returns:

  • (String)


2286
2287
2288
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2286

def client
  @client
end

#deal_typeString

Output only. Type of deal the proposal contains. Corresponds to the JSON property dealType

Returns:

  • (String)


2291
2292
2293
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2291

def deal_type
  @deal_type
end

#display_nameString

Output only. The descriptive name for the proposal. Maximum length of 255 unicode characters is allowed. Control characters are not allowed. Buyers cannot update this field. Note: Not to be confused with name, which is a unique identifier of the proposal. Corresponds to the JSON property displayName

Returns:

  • (String)


2299
2300
2301
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2299

def display_name
  @display_name
end

#is_renegotiatingBoolean Also known as: is_renegotiating?

Output only. True if the proposal was previously finalized and is now being renegotiated. Corresponds to the JSON property isRenegotiating

Returns:

  • (Boolean)


2305
2306
2307
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2305

def is_renegotiating
  @is_renegotiating
end

#last_updater_or_commentor_roleString

Output only. The role of the last user that either updated the proposal or left a comment. Corresponds to the JSON property lastUpdaterOrCommentorRole

Returns:

  • (String)


2312
2313
2314
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2312

def last_updater_or_commentor_role
  @last_updater_or_commentor_role
end

#nameString

Immutable. The name of the proposal serving as a unique identifier. Format: buyers/accountId/proposals/proposalId Corresponds to the JSON property name

Returns:

  • (String)


2318
2319
2320
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2318

def name
  @name
end

#notesArray<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Note>

A list of notes from the buyer and the seller attached to this proposal. Corresponds to the JSON property notes



2323
2324
2325
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2323

def notes
  @notes
end

#originator_roleString

Output only. Indicates whether the buyer/seller created the proposal. Corresponds to the JSON property originatorRole

Returns:

  • (String)


2328
2329
2330
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2328

def originator_role
  @originator_role
end

#pausing_consentedBoolean Also known as: pausing_consented?

Whether pausing is allowed for the proposal. This is a negotiable term between buyers and publishers. Corresponds to the JSON property pausingConsented

Returns:

  • (Boolean)


2334
2335
2336
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2334

def pausing_consented
  @pausing_consented
end

#proposal_revisionFixnum

Output only. The revision number for the proposal. Each update to the proposal or deal causes the proposal revision number to auto-increment. The buyer keeps track of the last revision number they know of and pass it in when making an update. If the head revision number on the server has since incremented, then an ABORTED error is returned during the update operation to let the buyer know that a subsequent update was made. Corresponds to the JSON property proposalRevision

Returns:

  • (Fixnum)


2345
2346
2347
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2345

def proposal_revision
  @proposal_revision
end

#publisher_profileString

Immutable. Reference to the seller on the proposal. Format: buyers/ buyerAccountId/publisherProfiles/publisherProfileId`Note: This field may be set only when creating the resource. Modifying this field while updating the resource will result in an error. Corresponds to the JSON propertypublisherProfile`

Returns:

  • (String)


2353
2354
2355
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2353

def publisher_profile
  @publisher_profile
end

#seller_contactsArray<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Contact>

Output only. Contact information for the seller. Corresponds to the JSON property sellerContacts



2358
2359
2360
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2358

def seller_contacts
  @seller_contacts
end

#stateString

Output only. Indicates the state of the proposal. Corresponds to the JSON property state

Returns:

  • (String)


2363
2364
2365
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2363

def state
  @state
end

#terms_and_conditionsString

Output only. The terms and conditions associated with this proposal. Accepting a proposal implies acceptance of this field. This is created by the seller, the buyer can only view it. Corresponds to the JSON property termsAndConditions

Returns:

  • (String)


2370
2371
2372
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2370

def terms_and_conditions
  @terms_and_conditions
end

#update_timeString

Output only. The time when the proposal was last revised. Corresponds to the JSON property updateTime

Returns:

  • (String)


2375
2376
2377
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2375

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
2397
2398
2399
2400
2401
2402
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2382

def update!(**args)
  @billed_buyer = args[:billed_buyer] if args.key?(:billed_buyer)
  @buyer = args[:buyer] if args.key?(:buyer)
  @buyer_contacts = args[:buyer_contacts] if args.key?(:buyer_contacts)
  @buyer_private_data = args[:buyer_private_data] if args.key?(:buyer_private_data)
  @client = args[:client] if args.key?(:client)
  @deal_type = args[:deal_type] if args.key?(:deal_type)
  @display_name = args[:display_name] if args.key?(:display_name)
  @is_renegotiating = args[:is_renegotiating] if args.key?(:is_renegotiating)
  @last_updater_or_commentor_role = args[:last_updater_or_commentor_role] if args.key?(:last_updater_or_commentor_role)
  @name = args[:name] if args.key?(:name)
  @notes = args[:notes] if args.key?(:notes)
  @originator_role = args[:originator_role] if args.key?(:originator_role)
  @pausing_consented = args[:pausing_consented] if args.key?(:pausing_consented)
  @proposal_revision = args[:proposal_revision] if args.key?(:proposal_revision)
  @publisher_profile = args[:publisher_profile] if args.key?(:publisher_profile)
  @seller_contacts = args[:seller_contacts] if args.key?(:seller_contacts)
  @state = args[:state] if args.key?(:state)
  @terms_and_conditions = args[:terms_and_conditions] if args.key?(:terms_and_conditions)
  @update_time = args[:update_time] if args.key?(:update_time)
end