Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PublisherProfile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

The values in the publisher profile are supplied by the publisher. All fields are not filterable unless stated otherwise.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublisherProfile

Returns a new instance of PublisherProfile.



2508
2509
2510
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2508

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audience_descriptionString

Description on the publisher's audience. Corresponds to the JSON property audienceDescription

Returns:

  • (String)


2413
2414
2415
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2413

def audience_description
  @audience_description
end

#direct_deals_contactString

Contact information for direct reservation deals. This is free text entered by the publisher and may include information like names, phone numbers and email addresses. Corresponds to the JSON property directDealsContact

Returns:

  • (String)


2420
2421
2422
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2420

def direct_deals_contact
  @direct_deals_contact
end

#display_nameString

Display name of the publisher profile. Can be used to filter the response of the publisherProfiles.list method. Corresponds to the JSON property displayName

Returns:

  • (String)


2426
2427
2428
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2426

def display_name
  @display_name
end

#domainsArray<String>

The list of domains represented in this publisher profile. Empty if this is a parent profile. These are top private domains, meaning that these will not contain a string like "photos.google.co.uk/123", but will instead contain " google.co.uk". Can be used to filter the response of the publisherProfiles. list method. Corresponds to the JSON property domains

Returns:

  • (Array<String>)


2435
2436
2437
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2435

def domains
  @domains
end

#is_parentBoolean Also known as: is_parent?

Indicates if this profile is the parent profile of the seller. A parent profile represents all the inventory from the seller, as opposed to child profile that is created to brand a portion of inventory. One seller has only one parent publisher profile, and can have multiple child profiles. See https:/ /support.google.com/admanager/answer/6035806 for details. Can be used to filter the response of the publisherProfiles.list method by setting the filter to "is_parent: true". Corresponds to the JSON property isParent

Returns:

  • (Boolean)


2446
2447
2448
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2446

def is_parent
  @is_parent
end

#logo_urlString

A Google public URL to the logo for this publisher profile. The logo is stored as a PNG, JPG, or GIF image. Corresponds to the JSON property logoUrl

Returns:

  • (String)


2453
2454
2455
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2453

def logo_url
  @logo_url
end

#media_kit_urlString

URL to additional marketing and sales materials. Corresponds to the JSON property mediaKitUrl

Returns:

  • (String)


2458
2459
2460
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2458

def media_kit_url
  @media_kit_url
end

#mobile_appsArray<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PublisherProfileMobileApplication>

The list of apps represented in this publisher profile. Empty if this is a parent profile. Corresponds to the JSON property mobileApps



2464
2465
2466
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2464

def mobile_apps
  @mobile_apps
end

#nameString

Name of the publisher profile. Format: buyers/buyer/publisherProfiles/ publisher_profile` Corresponds to the JSON propertyname`

Returns:

  • (String)


2470
2471
2472
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2470

def name
  @name
end

#overviewString

Overview of the publisher. Corresponds to the JSON property overview

Returns:

  • (String)


2475
2476
2477
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2475

def overview
  @overview
end

#pitch_statementString

Statement explaining what's unique about publisher's business, and why buyers should partner with the publisher. Corresponds to the JSON property pitchStatement

Returns:

  • (String)


2481
2482
2483
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2481

def pitch_statement
  @pitch_statement
end

#programmatic_deals_contactString

Contact information for programmatic deals. This is free text entered by the publisher and may include information like names, phone numbers and email addresses. Corresponds to the JSON property programmaticDealsContact

Returns:

  • (String)


2488
2489
2490
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2488

def programmatic_deals_contact
  @programmatic_deals_contact
end

#publisher_codeString

A unique identifying code for the seller. This value is the same for all of the seller's parent and child publisher profiles. Can be used to filter the response of the publisherProfiles.list method. Corresponds to the JSON property publisherCode

Returns:

  • (String)


2495
2496
2497
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2495

def publisher_code
  @publisher_code
end

#sample_page_urlString

URL to a sample content page. Corresponds to the JSON property samplePageUrl

Returns:

  • (String)


2500
2501
2502
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2500

def sample_page_url
  @sample_page_url
end

#top_headlinesArray<String>

Up to three key metrics and rankings. For example, "#1 Mobile News Site for 20 Straight Months". Corresponds to the JSON property topHeadlines

Returns:

  • (Array<String>)


2506
2507
2508
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2506

def top_headlines
  @top_headlines
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2513
2514
2515
2516
2517
2518
2519
2520
2521
2522
2523
2524
2525
2526
2527
2528
2529
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2513

def update!(**args)
  @audience_description = args[:audience_description] if args.key?(:audience_description)
  @direct_deals_contact = args[:direct_deals_contact] if args.key?(:direct_deals_contact)
  @display_name = args[:display_name] if args.key?(:display_name)
  @domains = args[:domains] if args.key?(:domains)
  @is_parent = args[:is_parent] if args.key?(:is_parent)
  @logo_url = args[:logo_url] if args.key?(:logo_url)
  @media_kit_url = args[:media_kit_url] if args.key?(:media_kit_url)
  @mobile_apps = args[:mobile_apps] if args.key?(:mobile_apps)
  @name = args[:name] if args.key?(:name)
  @overview = args[:overview] if args.key?(:overview)
  @pitch_statement = args[:pitch_statement] if args.key?(:pitch_statement)
  @programmatic_deals_contact = args[:programmatic_deals_contact] if args.key?(:programmatic_deals_contact)
  @publisher_code = args[:publisher_code] if args.key?(:publisher_code)
  @sample_page_url = args[:sample_page_url] if args.key?(:sample_page_url)
  @top_headlines = args[:top_headlines] if args.key?(:top_headlines)
end