Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PublisherProfile
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PublisherProfile
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
The values in the publisher profile are supplied by the publisher. All fields are not filterable unless stated otherwise.
Instance Attribute Summary collapse
-
#audience_description ⇒ String
Description on the publisher's audience.
-
#direct_deals_contact ⇒ String
Contact information for direct reservation deals.
-
#display_name ⇒ String
Display name of the publisher profile.
-
#domains ⇒ Array<String>
The list of domains represented in this publisher profile.
-
#is_parent ⇒ Boolean
(also: #is_parent?)
Indicates if this profile is the parent profile of the seller.
-
#logo_url ⇒ String
A Google public URL to the logo for this publisher profile.
-
#media_kit_url ⇒ String
URL to additional marketing and sales materials.
-
#mobile_apps ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PublisherProfileMobileApplication>
The list of apps represented in this publisher profile.
-
#name ⇒ String
Name of the publisher profile.
-
#overview ⇒ String
Overview of the publisher.
-
#pitch_statement ⇒ String
Statement explaining what's unique about publisher's business, and why buyers should partner with the publisher.
-
#programmatic_deals_contact ⇒ String
Contact information for programmatic deals.
-
#publisher_code ⇒ String
A unique identifying code for the seller.
-
#sample_page_url ⇒ String
URL to a sample content page.
-
#top_headlines ⇒ Array<String>
Up to three key metrics and rankings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublisherProfile
constructor
A new instance of PublisherProfile.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublisherProfile
Returns a new instance of PublisherProfile.
2494 2495 2496 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2494 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audience_description ⇒ String
Description on the publisher's audience.
Corresponds to the JSON property audienceDescription
2399 2400 2401 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2399 def audience_description @audience_description end |
#direct_deals_contact ⇒ String
Contact information for direct reservation deals. This is free text entered by
the publisher and may include information like names, phone numbers and email
addresses.
Corresponds to the JSON property directDealsContact
2406 2407 2408 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2406 def direct_deals_contact @direct_deals_contact end |
#display_name ⇒ String
Display name of the publisher profile. Can be used to filter the response of
the publisherProfiles.list method.
Corresponds to the JSON property displayName
2412 2413 2414 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2412 def display_name @display_name end |
#domains ⇒ Array<String>
The list of domains represented in this publisher profile. Empty if this is a
parent profile. These are top private domains, meaning that these will not
contain a string like "photos.google.co.uk/123", but will instead contain "
google.co.uk". Can be used to filter the response of the publisherProfiles.
list method.
Corresponds to the JSON property domains
2421 2422 2423 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2421 def domains @domains end |
#is_parent ⇒ Boolean Also known as: is_parent?
Indicates if this profile is the parent profile of the seller. A parent
profile represents all the inventory from the seller, as opposed to child
profile that is created to brand a portion of inventory. One seller has only
one parent publisher profile, and can have multiple child profiles. See https:/
/support.google.com/admanager/answer/6035806 for details. Can be used to
filter the response of the publisherProfiles.list method by setting the filter
to "is_parent: true".
Corresponds to the JSON property isParent
2432 2433 2434 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2432 def is_parent @is_parent end |
#logo_url ⇒ String
A Google public URL to the logo for this publisher profile. The logo is stored
as a PNG, JPG, or GIF image.
Corresponds to the JSON property logoUrl
2439 2440 2441 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2439 def logo_url @logo_url end |
#media_kit_url ⇒ String
URL to additional marketing and sales materials.
Corresponds to the JSON property mediaKitUrl
2444 2445 2446 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2444 def media_kit_url @media_kit_url end |
#mobile_apps ⇒ Array<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PublisherProfileMobileApplication>
The list of apps represented in this publisher profile. Empty if this is a
parent profile.
Corresponds to the JSON property mobileApps
2450 2451 2452 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2450 def mobile_apps @mobile_apps end |
#name ⇒ String
Name of the publisher profile. Format: buyers/buyer/publisherProfiles/
publisher_profile`
Corresponds to the JSON propertyname`
2456 2457 2458 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2456 def name @name end |
#overview ⇒ String
Overview of the publisher.
Corresponds to the JSON property overview
2461 2462 2463 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2461 def overview @overview end |
#pitch_statement ⇒ String
Statement explaining what's unique about publisher's business, and why buyers
should partner with the publisher.
Corresponds to the JSON property pitchStatement
2467 2468 2469 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2467 def pitch_statement @pitch_statement end |
#programmatic_deals_contact ⇒ String
Contact information for programmatic deals. This is free text entered by the
publisher and may include information like names, phone numbers and email
addresses.
Corresponds to the JSON property programmaticDealsContact
2474 2475 2476 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2474 def programmatic_deals_contact @programmatic_deals_contact end |
#publisher_code ⇒ String
A unique identifying code for the seller. This value is the same for all of
the seller's parent and child publisher profiles. Can be used to filter the
response of the publisherProfiles.list method.
Corresponds to the JSON property publisherCode
2481 2482 2483 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2481 def publisher_code @publisher_code end |
#sample_page_url ⇒ String
URL to a sample content page.
Corresponds to the JSON property samplePageUrl
2486 2487 2488 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2486 def sample_page_url @sample_page_url end |
#top_headlines ⇒ Array<String>
Up to three key metrics and rankings. For example, "#1 Mobile News Site for 20
Straight Months".
Corresponds to the JSON property topHeadlines
2492 2493 2494 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2492 def top_headlines @top_headlines end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2499 2500 2501 2502 2503 2504 2505 2506 2507 2508 2509 2510 2511 2512 2513 2514 2515 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2499 def update!(**args) @audience_description = args[:audience_description] if args.key?(:audience_description) @direct_deals_contact = args[:direct_deals_contact] if args.key?(:direct_deals_contact) @display_name = args[:display_name] if args.key?(:display_name) @domains = args[:domains] if args.key?(:domains) @is_parent = args[:is_parent] if args.key?(:is_parent) @logo_url = args[:logo_url] if args.key?(:logo_url) @media_kit_url = args[:media_kit_url] if args.key?(:media_kit_url) @mobile_apps = args[:mobile_apps] if args.key?(:mobile_apps) @name = args[:name] if args.key?(:name) @overview = args[:overview] if args.key?(:overview) @pitch_statement = args[:pitch_statement] if args.key?(:pitch_statement) @programmatic_deals_contact = args[:programmatic_deals_contact] if args.key?(:programmatic_deals_contact) @publisher_code = args[:publisher_code] if args.key?(:publisher_code) @sample_page_url = args[:sample_page_url] if args.key?(:sample_page_url) @top_headlines = args[:top_headlines] if args.key?(:top_headlines) end |