Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PublisherProfileMobileApplication
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::PublisherProfileMobileApplication
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
A mobile application that contains a external app ID, name, and app store.
Instance Attribute Summary collapse
-
#app_store ⇒ String
The app store the app belongs to.
-
#external_app_id ⇒ String
The external ID for the app from its app store.
-
#name ⇒ String
The name of the app.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublisherProfileMobileApplication
constructor
A new instance of PublisherProfileMobileApplication.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublisherProfileMobileApplication
Returns a new instance of PublisherProfileMobileApplication.
2553 2554 2555 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_store ⇒ String
The app store the app belongs to. Can be used to filter the response of the
publisherProfiles.list method.
Corresponds to the JSON property appStore
2540 2541 2542 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2540 def app_store @app_store end |
#external_app_id ⇒ String
The external ID for the app from its app store. Can be used to filter the
response of the publisherProfiles.list method.
Corresponds to the JSON property externalAppId
2546 2547 2548 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2546 def external_app_id @external_app_id end |
#name ⇒ String
The name of the app.
Corresponds to the JSON property name
2551 2552 2553 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2551 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2558 2559 2560 2561 2562 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2558 def update!(**args) @app_store = args[:app_store] if args.key?(:app_store) @external_app_id = args[:external_app_id] if args.key?(:external_app_id) @name = args[:name] if args.key?(:name) end |