Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::SendRfpRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Request to send an RFP. All fields in this request are proposed to publisher and subject to changes by publisher during later negotiation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SendRfpRequest

Returns a new instance of SendRfpRequest.



2688
2689
2690
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2688

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#buyer_contactsArray<Google::Apis::AuthorizedbuyersmarketplaceV1alpha::Contact>

Contact information for the buyer. Corresponds to the JSON property buyerContacts



2622
2623
2624
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2622

def buyer_contacts
  @buyer_contacts
end

#clientString

If the current buyer is sending the RFP on behalf of its client, use this field to specify the name of the client in the format: buyers/accountId/ clients/clientAccountid`. Corresponds to the JSON propertyclient`

Returns:

  • (String)


2629
2630
2631
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2629

def client
  @client
end

#display_nameString

Required. The display name of the proposal being created by this RFP. Corresponds to the JSON property displayName

Returns:

  • (String)


2634
2635
2636
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2634

def display_name
  @display_name
end

#estimated_gross_spendGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::Money

Represents an amount of money with its currency type. Corresponds to the JSON property estimatedGrossSpend



2639
2640
2641
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2639

def estimated_gross_spend
  @estimated_gross_spend
end

#flight_end_timeString

Required. Proposed flight end time of the RFP. A timestamp in RFC3339 UTC " Zulu" format. Note that the specified value will be truncated to a granularity of one second. Corresponds to the JSON property flightEndTime

Returns:

  • (String)


2646
2647
2648
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2646

def flight_end_time
  @flight_end_time
end

#flight_start_timeString

Required. Proposed flight start time of the RFP. A timestamp in RFC3339 UTC " Zulu" format. Note that the specified value will be truncated to a granularity of one second. Corresponds to the JSON property flightStartTime

Returns:

  • (String)


2653
2654
2655
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2653

def flight_start_time
  @flight_start_time
end

#geo_targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting

Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs. This cannot be filtered using list filter syntax. Corresponds to the JSON property geoTargeting



2660
2661
2662
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2660

def geo_targeting
  @geo_targeting
end

#inventory_size_targetingGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::InventorySizeTargeting

Represents the size of an ad unit that can be targeted on a bid request. Corresponds to the JSON property inventorySizeTargeting



2665
2666
2667
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2665

def inventory_size_targeting
  @inventory_size_targeting
end

#noteString

A message that is sent to the publisher. Maximum length is 1024 characters. Corresponds to the JSON property note

Returns:

  • (String)


2670
2671
2672
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2670

def note
  @note
end

#preferred_deal_termsGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::PreferredDealTerms

Pricing terms for Preferred Deals. Corresponds to the JSON property preferredDealTerms



2675
2676
2677
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2675

def preferred_deal_terms
  @preferred_deal_terms
end

#programmatic_guaranteed_termsGoogle::Apis::AuthorizedbuyersmarketplaceV1alpha::ProgrammaticGuaranteedTerms

Pricing terms for Programmatic Guaranteed Deals. Corresponds to the JSON property programmaticGuaranteedTerms



2680
2681
2682
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2680

def programmatic_guaranteed_terms
  @programmatic_guaranteed_terms
end

#publisher_profileString

Required. The profile of the publisher who will receive this RFP in the format: buyers/accountId/publisherProfiles/publisherProfileId`. Corresponds to the JSON propertypublisherProfile`

Returns:

  • (String)


2686
2687
2688
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2686

def publisher_profile
  @publisher_profile
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2693
2694
2695
2696
2697
2698
2699
2700
2701
2702
2703
2704
2705
2706
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2693

def update!(**args)
  @buyer_contacts = args[:buyer_contacts] if args.key?(:buyer_contacts)
  @client = args[:client] if args.key?(:client)
  @display_name = args[:display_name] if args.key?(:display_name)
  @estimated_gross_spend = args[:estimated_gross_spend] if args.key?(:estimated_gross_spend)
  @flight_end_time = args[:flight_end_time] if args.key?(:flight_end_time)
  @flight_start_time = args[:flight_start_time] if args.key?(:flight_start_time)
  @geo_targeting = args[:geo_targeting] if args.key?(:geo_targeting)
  @inventory_size_targeting = args[:inventory_size_targeting] if args.key?(:inventory_size_targeting)
  @note = args[:note] if args.key?(:note)
  @preferred_deal_terms = args[:preferred_deal_terms] if args.key?(:preferred_deal_terms)
  @programmatic_guaranteed_terms = args[:programmatic_guaranteed_terms] if args.key?(:programmatic_guaranteed_terms)
  @publisher_profile = args[:publisher_profile] if args.key?(:publisher_profile)
end