Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::SubscribeClientsRequest
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::SubscribeClientsRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Request message for SubscribeAuctionPackageClients.
Instance Attribute Summary collapse
-
#clients ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubscribeClientsRequest
constructor
A new instance of SubscribeClientsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubscribeClientsRequest
Returns a new instance of SubscribeClientsRequest.
2772 2773 2774 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#clients ⇒ Array<String>
Optional. A list of client buyers to subscribe to the auction package, with
client buyer in the format buyers/accountId/clients/clientAccountId`. The
current buyer will be subscribed to the auction package regardless of the list
contents if not already.
Corresponds to the JSON propertyclients`
2770 2771 2772 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2770 def clients @clients end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2777 2778 2779 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2777 def update!(**args) @clients = args[:clients] if args.key?(:clients) end |