Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::TechnologyTargeting
- Inherits:
-
Object
- Object
- Google::Apis::AuthorizedbuyersmarketplaceV1alpha::TechnologyTargeting
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb
Overview
Represents targeting about various types of technology.
Instance Attribute Summary collapse
-
#device_capability_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
-
#device_category_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of included and excluded numeric IDs.
-
#operating_system_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::OperatingSystemTargeting
Represents targeting information for operating systems.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TechnologyTargeting
constructor
A new instance of TechnologyTargeting.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TechnologyTargeting
Returns a new instance of TechnologyTargeting.
2831 2832 2833 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#device_capability_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property deviceCapabilityTargeting
2817 2818 2819 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2817 def device_capability_targeting @device_capability_targeting end |
#device_category_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::CriteriaTargeting
Generic targeting used for targeting dimensions that contains a list of
included and excluded numeric IDs. This cannot be filtered using list filter
syntax.
Corresponds to the JSON property deviceCategoryTargeting
2824 2825 2826 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2824 def device_category_targeting @device_category_targeting end |
#operating_system_targeting ⇒ Google::Apis::AuthorizedbuyersmarketplaceV1alpha::OperatingSystemTargeting
Represents targeting information for operating systems.
Corresponds to the JSON property operatingSystemTargeting
2829 2830 2831 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2829 def @operating_system_targeting end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2836 2837 2838 2839 2840 |
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 2836 def update!(**args) @device_capability_targeting = args[:device_capability_targeting] if args.key?(:device_capability_targeting) @device_category_targeting = args[:device_category_targeting] if args.key?(:device_category_targeting) @operating_system_targeting = args[:operating_system_targeting] if args.key?(:operating_system_targeting) end |