Class: Google::Apis::AuthorizedbuyersmarketplaceV1alpha::VideoPlcmtTargeting

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb,
lib/google/apis/authorizedbuyersmarketplace_v1alpha/representations.rb

Overview

Defines targeting criteria based on the video placement type, often corresponding to the IAB OpenRTB 'plcmt' field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VideoPlcmtTargeting

Returns a new instance of VideoPlcmtTargeting.



3051
3052
3053
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 3051

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#selection_typeString

Required. The selection type for the list of video plcmts. Corresponds to the JSON property selectionType

Returns:

  • (String)


3043
3044
3045
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 3043

def selection_type
  @selection_type
end

#video_plcmt_typesArray<String>

Required. The list of targeted video plcmts types. If empty, inventory will be targeted regardless of video plcmt type. Corresponds to the JSON property videoPlcmtTypes

Returns:

  • (Array<String>)


3049
3050
3051
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 3049

def video_plcmt_types
  @video_plcmt_types
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3056
3057
3058
3059
# File 'lib/google/apis/authorizedbuyersmarketplace_v1alpha/classes.rb', line 3056

def update!(**args)
  @selection_type = args[:selection_type] if args.key?(:selection_type)
  @video_plcmt_types = args[:video_plcmt_types] if args.key?(:video_plcmt_types)
end